"""
PySide stub files generated by **IceSpringPySideStubs**

Home: https://baijifeilong.github.io/2022/01/06/ice-spring-pyside-stubs/index.html

Github: https://github.com/baijifeilong/IceSpringPySideStubs

PyPI(PySide2): https://pypi.org/project/IceSpringPySideStubs-PySide2

PyPI(PySide6): https://pypi.org/project/IceSpringPySideStubs-PySide6

PyPI(PyQt5): https://pypi.org/project/IceSpringPySideStubs-PyQt5

PyPI(PyQt6): https://pypi.org/project/IceSpringPySideStubs-PyQt6

Generated by BaiJiFeiLong@gmail.com

License: MIT
"""
from PyQt6 import QtCore


class QScrollPrepareEvent(QtCore.QEvent):
    """
    https://doc.qt.io/qt-6/qscrollprepareevent.html

    **Detailed Description**

    The scroll prepare event is sent before scrolling (usually by **QScroller**
    ) is started. The object receiving this event should set **viewportSize** ,
    maxContentPos and **contentPos** . It also should accept this event to
    indicate that scrolling should be started.

    It is not guaranteed that a **QScrollEvent**  will be sent after an accepted
    QScrollPrepareEvent, e.g. in a case where the maximum content position is
    (0, 0).

    **See also** **QScrollEvent**  and **QScroller** .
    """

    def __init__(self, startPos: QtCore.QPointF) -> None:
        """
        https://doc.qt.io/qt-6/qscrollprepareevent.html#QScrollPrepareEvent-2

        **QScrollPrepareEvent::QScrollPrepareEvent(const QPointF & startPos )**

        Creates new QScrollPrepareEvent The **startPos** is the position of a
        touch or mouse event that started the scrolling.
        """
        ...

    def clone(self) -> "QScrollPrepareEvent":
        ...

    def setContentPos(self, pos: QtCore.QPointF) -> None:
        """
        https://doc.qt.io/qt-6/qscrollprepareevent.html#setContentPos

        **void QScrollPrepareEvent::setContentPos(const QPointF & pos )**

        Sets the current content position to **pos**.

        **See also** **contentPos** ().
        """
        ...

    def setContentPosRange(self, rect: QtCore.QRectF) -> None:
        """
        https://doc.qt.io/qt-6/qscrollprepareevent.html#setContentPosRange

        **void QScrollPrepareEvent::setContentPosRange(const QRectF & rect )**

        Sets the range of content coordinates to **rect**.

        **See also** **contentPosRange** ().
        """
        ...

    def setViewportSize(self, size: QtCore.QSizeF) -> None:
        """
        https://doc.qt.io/qt-6/qscrollprepareevent.html#setViewportSize

        **void QScrollPrepareEvent::setViewportSize(const QSizeF & size )**

        Sets the size of the area that is to be scrolled to **size**.

        **See also** **viewportSize** ().
        """
        ...

    def contentPos(self) -> QtCore.QPointF:
        """
        https://doc.qt.io/qt-6/qscrollprepareevent.html#contentPos

        **QPointF QScrollPrepareEvent::contentPos() const**

        Returns the current position of the content as set by **setContentPos**
        .

        **See also** **setContentPos** ().
        """
        ...

    def contentPosRange(self) -> QtCore.QRectF:
        """
        https://doc.qt.io/qt-6/qscrollprepareevent.html#contentPosRange

        **QRectF QScrollPrepareEvent::contentPosRange() const**

        Returns the range of coordinates for the content as set by
        **setContentPosRange** ().

        **See also** **setContentPosRange** ().
        """
        ...

    def viewportSize(self) -> QtCore.QSizeF:
        """
        https://doc.qt.io/qt-6/qscrollprepareevent.html#viewportSize

        **QSizeF QScrollPrepareEvent::viewportSize() const**

        Returns size of the area that is to be scrolled as set by
        **setViewportSize**

        **See also** **setViewportSize** ().
        """
        ...

    def startPos(self) -> QtCore.QPointF:
        """
        https://doc.qt.io/qt-6/qscrollprepareevent.html#startPos

        **QPointF QScrollPrepareEvent::startPos() const**

        Returns the position of the touch or mouse event that started the
        scrolling.
        """
        ...



"""
PySide stub files generated by **IceSpringPySideStubs**

Home: https://baijifeilong.github.io/2022/01/06/ice-spring-pyside-stubs/index.html

Github: https://github.com/baijifeilong/IceSpringPySideStubs

PyPI(PySide2): https://pypi.org/project/IceSpringPySideStubs-PySide2

PyPI(PySide6): https://pypi.org/project/IceSpringPySideStubs-PySide6

PyPI(PyQt5): https://pypi.org/project/IceSpringPySideStubs-PyQt5

PyPI(PyQt6): https://pypi.org/project/IceSpringPySideStubs-PyQt6

Generated by BaiJiFeiLong@gmail.com

License: MIT
"""
import typing
import PyQt6.sip
from PyQt6.QtWidgets import *


class QStyleFactory(PyQt6.sip.simplewrapper):
    """
    https://doc.qt.io/qt-6/qstylefactory.html

    **Detailed Description**

    The **QStyle**  class is an abstract base class that encapsulates the look
    and feel of a GUI. QStyleFactory creates a **QStyle**  object using the
    **create** () function and a key identifying the style. The styles are
    either built-in or dynamically loaded from a style plugin (see
    **QStylePlugin** ).

    The valid keys can be retrieved using the **keys** () function. Typically
    they include "windows" and "fusion". Depending on the platform,
    "windowsvista" and "macos" may be available. Note that keys are case
    insensitive.

    **See also** **QStyle** .
    """

    @typing.overload
    def __init__(self) -> None:
        ...

    @typing.overload
    def __init__(self, a0: "QStyleFactory") -> None:
        ...

    @staticmethod
    def create(a0: str) -> QStyle:
        """
        https://doc.qt.io/qt-6/qstylefactory.html#create

        **[static] QStyle *QStyleFactory::create(const QString & key )**

        Creates and returns a **QStyle**  object that matches the given **key**
        , or returns `nullptr` if no matching style is found.

        Both built-in styles and styles from style plugins are queried for a
        matching style.

        **Note:** The keys used are case insensitive.

        **See also** **keys** ().
        """
        ...

    @staticmethod
    def keys() -> typing.List[str]:
        """
        https://doc.qt.io/qt-6/qstylefactory.html#keys

        **[static] QStringList QStyleFactory::keys()**

        Returns the list of valid keys, i.e. the keys this factory can create
        styles for.

        **See also** **create** ().
        """
        ...



"""
PySide stub files generated by **IceSpringPySideStubs**

Home: https://baijifeilong.github.io/2022/01/06/ice-spring-pyside-stubs/index.html

Github: https://github.com/baijifeilong/IceSpringPySideStubs

PyPI(PySide2): https://pypi.org/project/IceSpringPySideStubs-PySide2

PyPI(PySide6): https://pypi.org/project/IceSpringPySideStubs-PySide6

PyPI(PyQt5): https://pypi.org/project/IceSpringPySideStubs-PyQt5

PyPI(PyQt6): https://pypi.org/project/IceSpringPySideStubs-PyQt6

Generated by BaiJiFeiLong@gmail.com

License: MIT
"""
from PyQt6 import QtCore


class QShowEvent(QtCore.QEvent):
    """
    https://doc.qt.io/qt-6/qshowevent.html

    **Detailed Description**

    There are two kinds of show events: show events caused by the window system
    (spontaneous), and internal show events. Spontaneous
    (**QEvent::spontaneous** ()) show events are sent just after the window
    system shows the window; they are also sent when a top-level window is
    redisplayed after being iconified. Internal show events are delivered just
    before the widget becomes visible.

    **See also** **QHideEvent** .
    """

    def __init__(self) -> None:
        """
        https://doc.qt.io/qt-6/qshowevent.html#QShowEvent-2

        **QShowEvent::QShowEvent()**

        Constructs a QShowEvent.
        """
        ...



"""
PySide stub files generated by **IceSpringPySideStubs**

Home: https://baijifeilong.github.io/2022/01/06/ice-spring-pyside-stubs/index.html

Github: https://github.com/baijifeilong/IceSpringPySideStubs

PyPI(PySide2): https://pypi.org/project/IceSpringPySideStubs-PySide2

PyPI(PySide6): https://pypi.org/project/IceSpringPySideStubs-PySide6

PyPI(PyQt5): https://pypi.org/project/IceSpringPySideStubs-PyQt5

PyPI(PyQt6): https://pypi.org/project/IceSpringPySideStubs-PyQt6

Generated by BaiJiFeiLong@gmail.com

License: MIT
"""
import typing
import PyQt6.sip
from PyQt6 import QtCore
import datetime
from PyQt6.QtNetwork import *


class QNetworkCacheMetaData(PyQt6.sip.simplewrapper):
    """
    https://doc.qt.io/qt-6/qnetworkcachemetadata.html

    **Detailed Description**

    QNetworkCacheMetaData provides information about a cache file including the
    url, when it was last modified, when the cache file was created, headers for
    file and if the file should be saved onto a disk.

    **See also** **QAbstractNetworkCache** .
    """

    @typing.overload
    def __init__(self) -> None:
        """
        https://doc.qt.io/qt-6/qnetworkcachemetadata.html#QNetworkCacheMetaData

        **QNetworkCacheMetaData::QNetworkCacheMetaData()**

        Constructs an invalid network cache meta data.

        **See also** **isValid** ().
        """
        ...

    @typing.overload
    def __init__(self, other: "QNetworkCacheMetaData") -> None:
        """
        https://doc.qt.io/qt-6/qnetworkcachemetadata.html#QNetworkCacheMetaData-
        1

        **QNetworkCacheMetaData::QNetworkCacheMetaData(const
        QNetworkCacheMetaData & other )**

        Constructs a copy of the **other** QNetworkCacheMetaData.
        """
        ...

    def swap(self, other: "QNetworkCacheMetaData") -> None:
        """
        https://doc.qt.io/qt-6/qnetworkcachemetadata.html#swap

        **[since 5.0] void QNetworkCacheMetaData::swap(QNetworkCacheMetaData &
        other )**

        Swaps this metadata instance with **other**. This function is very fast
        and never fails.

        This function was introduced in Qt 5.0.
        """
        ...

    def setAttributes(
        self, attributes: typing.Dict["QNetworkRequest.Attribute", typing.Any]
    ) -> None:
        """
        https://doc.qt.io/qt-6/qnetworkcachemetadata.html#setAttributes

        **void QNetworkCacheMetaData::setAttributes(const
        QNetworkCacheMetaData::AttributesMap & attributes )**

        Sets all attributes of this cache item to be the map **attributes**.

        **See also** **attributes** () and **QNetworkRequest::setAttribute** ().
        """
        ...

    def attributes(self) -> typing.Dict["QNetworkRequest.Attribute", typing.Any]:
        """
        https://doc.qt.io/qt-6/qnetworkcachemetadata.html#attributes

        **QNetworkCacheMetaData::AttributesMap
        QNetworkCacheMetaData::attributes() const**

        Returns all the attributes stored with this cache item.

        **See also** **setAttributes** () and **QNetworkRequest::Attribute** .
        """
        ...

    def setSaveToDisk(self, allow: bool) -> None:
        """
        https://doc.qt.io/qt-6/qnetworkcachemetadata.html#setSaveToDisk

        **void QNetworkCacheMetaData::setSaveToDisk(bool allow )**

        Sets whether this network cache meta data and associated content should
        be allowed to be stored on disk to **allow**.

        **See also** **saveToDisk** ().
        """
        ...

    def saveToDisk(self) -> bool:
        """
        https://doc.qt.io/qt-6/qnetworkcachemetadata.html#saveToDisk

        **bool QNetworkCacheMetaData::saveToDisk() const**

        Returns is this cache should be allowed to be stored on disk.

        Some cache implementations can keep these cache items in memory for
        performance reasons, but for security reasons they should not be written
        to disk.

        Specifically with http, documents with Cache-control set to no-store or
        any https document that doesn't have "Cache-control: public" set will
        set the saveToDisk to false.

        **See also** **setSaveToDisk** ().
        """
        ...

    def setExpirationDate(
        self, dateTime: typing.Union[QtCore.QDateTime, datetime.datetime]
    ) -> None:
        """
        https://doc.qt.io/qt-6/qnetworkcachemetadata.html#setExpirationDate

        **void QNetworkCacheMetaData::setExpirationDate(const QDateTime &
        dateTime )**

        Sets the date and time when the meta data expires to **dateTime**.

        **See also** **expirationDate** ().
        """
        ...

    def expirationDate(self) -> QtCore.QDateTime:
        """
        https://doc.qt.io/qt-6/qnetworkcachemetadata.html#expirationDate

        **QDateTime QNetworkCacheMetaData::expirationDate() const**

        Returns the date and time when the meta data expires.

        **See also** **setExpirationDate** ().
        """
        ...

    def setLastModified(
        self, dateTime: typing.Union[QtCore.QDateTime, datetime.datetime]
    ) -> None:
        """
        https://doc.qt.io/qt-6/qnetworkcachemetadata.html#setLastModified

        **void QNetworkCacheMetaData::setLastModified(const QDateTime & dateTime
        )**

        Sets the date and time when the meta data was last modified to
        **dateTime**.

        **See also** **lastModified** ().
        """
        ...

    def lastModified(self) -> QtCore.QDateTime:
        """
        https://doc.qt.io/qt-6/qnetworkcachemetadata.html#lastModified

        **QDateTime QNetworkCacheMetaData::lastModified() const**

        Returns the date and time when the meta data was last modified.

        **See also** **setLastModified** ().
        """
        ...

    def setRawHeaders(
        self,
        headers: typing.Iterable[typing.Tuple[QtCore.QByteArray, QtCore.QByteArray]],
    ) -> None:
        """
        https://doc.qt.io/qt-6/qnetworkcachemetadata.html#setRawHeaders

        **void QNetworkCacheMetaData::setRawHeaders(const
        QNetworkCacheMetaData::RawHeaderList & list )**

        Sets the raw headers to **list**.

        **See also** **rawHeaders** ().
        """
        ...

    def rawHeaders(
        self,
    ) -> typing.List[typing.Tuple[QtCore.QByteArray, QtCore.QByteArray]]:
        """
        https://doc.qt.io/qt-6/qnetworkcachemetadata.html#rawHeaders

        **QNetworkCacheMetaData::RawHeaderList
        QNetworkCacheMetaData::rawHeaders() const**

        Returns a list of all raw headers that are set in this meta data. The
        list is in the same order that the headers were set.

        **See also** **setRawHeaders** ().
        """
        ...

    def setUrl(self, url: QtCore.QUrl) -> None:
        """
        https://doc.qt.io/qt-6/qnetworkcachemetadata.html#setUrl

        **void QNetworkCacheMetaData::setUrl(const QUrl & url )**

        Sets the URL this network cache meta data to be **url**.

        The password and fragment are removed from the url.

        **See also** **url** ().
        """
        ...

    def url(self) -> QtCore.QUrl:
        """
        https://doc.qt.io/qt-6/qnetworkcachemetadata.html#url

        **QUrl QNetworkCacheMetaData::url() const**

        Returns the URL this network cache meta data is referring to.

        **See also** **setUrl** ().
        """
        ...

    def isValid(self) -> bool:
        """
        https://doc.qt.io/qt-6/qnetworkcachemetadata.html#isValid

        **bool QNetworkCacheMetaData::isValid() const**

        Returns `true` if this network cache meta data has attributes that have
        been set otherwise false.
        """
        ...



"""
PySide stub files generated by **IceSpringPySideStubs**

Home: https://baijifeilong.github.io/2022/01/06/ice-spring-pyside-stubs/index.html

Github: https://github.com/baijifeilong/IceSpringPySideStubs

PyPI(PySide2): https://pypi.org/project/IceSpringPySideStubs-PySide2

PyPI(PySide6): https://pypi.org/project/IceSpringPySideStubs-PySide6

PyPI(PyQt5): https://pypi.org/project/IceSpringPySideStubs-PyQt5

PyPI(PyQt6): https://pypi.org/project/IceSpringPySideStubs-PyQt6

Generated by BaiJiFeiLong@gmail.com

License: MIT
"""
import typing
from PyQt6 import QtCore
from PyQt6.QtWidgets import *


class QPanGesture(QGesture):
    """
    https://doc.qt.io/qt-6/qpangesture.html

    **Detailed Description**

    ![](images/pangesture.png)

    For an overview of gesture handling in Qt and information on using gestures
    in your applications, see the **Gestures in Widgets and Graphics View**
    document.

    **See also** **QPinchGesture**  and **QSwipeGesture** .
    """

    def __init__(self, parent: typing.Optional[QtCore.QObject] = ...) -> None:
        ...

    def setAcceleration(self, value: float) -> None:
        """
        https://doc.qt.io/qt-6/qpangesture.html#acceleration-prop

        **acceleration : qreal**

        This property holds the acceleration in the motion of the touch point
        for this gesture

        **Access functions:**

        qreal **acceleration** () const
        void **setAcceleration** (qreal
        **value** )
        """
        ...

    def setOffset(self, value: QtCore.QPointF) -> None:
        """
        https://doc.qt.io/qt-6/qpangesture.html#offset-prop

        **offset : QPointF**

        This property holds the total offset from the first input position to
        the current input position

        The offset measures the total change in position of the user's input
        covered by the gesture on the input device.

        **Access functions:**

        QPointF **offset** () const
        void **setOffset** (const QPointF &
        **value** )

        **Member Function Documentation**
        """
        ...

    def setLastOffset(self, value: QtCore.QPointF) -> None:
        """
        https://doc.qt.io/qt-6/qpangesture.html#lastOffset-prop

        **lastOffset : QPointF**

        This property holds the last offset recorded for this gesture

        The last offset contains the change in position of the user's input as
        reported in the **offset**  property when a previous gesture event was
        delivered for this gesture.

        If no previous event was delivered with information about this gesture
        (i.e., this gesture object contains information about the first movement
        in the gesture) then this property contains a zero size.

        **Access functions:**

        QPointF **lastOffset** () const
        void **setLastOffset** (const QPointF
        & **value** )
        """
        ...

    def acceleration(self) -> float:
        """
        https://doc.qt.io/qt-6/qpangesture.html#acceleration-prop

        **acceleration : qreal**

        This property holds the acceleration in the motion of the touch point
        for this gesture

        **Access functions:**

        qreal **acceleration** () const
        void **setAcceleration** (qreal
        **value** )
        """
        ...

    def delta(self) -> QtCore.QPointF:
        """
        https://doc.qt.io/qt-6/qpangesture.html#delta-prop

        **[read-only] delta : const QPointF**

        This property holds the offset from the previous input position to the
        current input

        This is essentially the same as the difference between **offset** () and
        **lastOffset** ().

        **Access functions:**

        QPointF **delta** () const
        """
        ...

    def offset(self) -> QtCore.QPointF:
        """
        https://doc.qt.io/qt-6/qpangesture.html#offset-prop

        **offset : QPointF**

        This property holds the total offset from the first input position to
        the current input position

        The offset measures the total change in position of the user's input
        covered by the gesture on the input device.

        **Access functions:**

        QPointF **offset** () const
        void **setOffset** (const QPointF &
        **value** )

        **Member Function Documentation**
        """
        ...

    def lastOffset(self) -> QtCore.QPointF:
        """
        https://doc.qt.io/qt-6/qpangesture.html#lastOffset-prop

        **lastOffset : QPointF**

        This property holds the last offset recorded for this gesture

        The last offset contains the change in position of the user's input as
        reported in the **offset**  property when a previous gesture event was
        delivered for this gesture.

        If no previous event was delivered with information about this gesture
        (i.e., this gesture object contains information about the first movement
        in the gesture) then this property contains a zero size.

        **Access functions:**

        QPointF **lastOffset** () const
        void **setLastOffset** (const QPointF
        & **value** )
        """
        ...



"""
PySide stub files generated by **IceSpringPySideStubs**

Home: https://baijifeilong.github.io/2022/01/06/ice-spring-pyside-stubs/index.html

Github: https://github.com/baijifeilong/IceSpringPySideStubs

PyPI(PySide2): https://pypi.org/project/IceSpringPySideStubs-PySide2

PyPI(PySide6): https://pypi.org/project/IceSpringPySideStubs-PySide6

PyPI(PyQt5): https://pypi.org/project/IceSpringPySideStubs-PyQt5

PyPI(PyQt6): https://pypi.org/project/IceSpringPySideStubs-PyQt6

Generated by BaiJiFeiLong@gmail.com

License: MIT
"""
import typing
import PyQt6.sip
from PyQt6.QtCore import *


class QAbstractProxyModel(QAbstractItemModel):
    """
    https://doc.qt.io/qt-6/qabstractproxymodel.html

    **Detailed Description**

    This class defines the standard interface that proxy models must use to be
    able to interoperate correctly with other model/view components. It is not
    supposed to be instantiated directly.

    All standard proxy models are derived from the QAbstractProxyModel class. If
    you need to create a new proxy model class, it is usually better to subclass
    an existing class that provides the closest behavior to the one you want to
    provide.

    Proxy models that filter or sort items of data from a source model should be
    created by using or subclassing **QSortFilterProxyModel** .

    To subclass QAbstractProxyModel, you need to implement **mapFromSource** ()
    and **mapToSource** (). The **mapSelectionFromSource** () and
    **mapSelectionToSource** () functions only need to be reimplemented if you
    need a behavior different from the default behavior.

    **Note:** If the source model is deleted or no source model is specified,
    the proxy model operates on a empty placeholder model.

    **See also** **QSortFilterProxyModel** , **QAbstractItemModel** , and
    **Model/View Programming** .
    """

    def __init__(self, parent: typing.Optional[QObject] = ...) -> None:
        """
        https://doc.qt.io/qt-6/qabstractproxymodel.html#QAbstractProxyModel

        **QAbstractProxyModel::QAbstractProxyModel(QObject * parent = nullptr)**

        Constructs a proxy model with the given **parent**.
        """
        ...

    def roleNames(self) -> typing.Dict[int, "QByteArray"]:
        """
        https://doc.qt.io/qt-6/qabstractproxymodel.html#roleNames

        **[override virtual] QHash<int, QByteArray>
        QAbstractProxyModel::roleNames() const**

        Reimplements: **QAbstractItemModel::roleNames() const** .
        """
        ...

    def clearItemData(self, index: QModelIndex) -> bool:
        """
        https://doc.qt.io/qt-6/qabstractproxymodel.html#clearItemData

        **[override virtual, since 6.0] bool
        QAbstractProxyModel::clearItemData(const QModelIndex & index )**

        Reimplements: **QAbstractItemModel::clearItemData** (const QModelIndex
        &index).

        This function was introduced in Qt 6.0.
        """
        ...

    def supportedDragActions(self) -> Qt.DropAction:
        """
        https://doc.qt.io/qt-6/qabstractproxymodel.html#supportedDragActions

        **[override virtual] Qt::DropActions
        QAbstractProxyModel::supportedDragActions() const**

        Reimplements: **QAbstractItemModel::supportedDragActions() const** .
        """
        ...

    def dropMimeData(
        self,
        data: "QMimeData",
        action: Qt.DropAction,
        row: int,
        column: int,
        parent: QModelIndex,
    ) -> bool:
        """
        https://doc.qt.io/qt-6/qabstractproxymodel.html#dropMimeData

        **[override virtual, since 5.4] bool
        QAbstractProxyModel::dropMimeData(const QMimeData * data ,
        Qt::DropAction action , int row , int column , const QModelIndex &
        parent )**

        Reimplements: **QAbstractItemModel::dropMimeData** (const QMimeData
        *data, Qt::DropAction action, int row, int column, const QModelIndex
        &parent).

        This function was introduced in Qt 5.4.
        """
        ...

    def canDropMimeData(
        self,
        data: "QMimeData",
        action: Qt.DropAction,
        row: int,
        column: int,
        parent: QModelIndex,
    ) -> bool:
        """
        https://doc.qt.io/qt-6/qabstractproxymodel.html#canDropMimeData

        **[override virtual, since 5.4] bool
        QAbstractProxyModel::canDropMimeData(const QMimeData * data ,
        Qt::DropAction action , int row , int column , const QModelIndex &
        parent ) const**

        Reimplements: **QAbstractItemModel::canDropMimeData(const QMimeData
        *data, Qt::DropAction action, int row, int column, const QModelIndex
        &parent) const** .

        This function was introduced in Qt 5.4.
        """
        ...

    def sibling(self, row: int, column: int, idx: QModelIndex) -> QModelIndex:
        """
        https://doc.qt.io/qt-6/qabstractproxymodel.html#sibling

        **[override virtual] QModelIndex QAbstractProxyModel::sibling(int row ,
        int column , const QModelIndex & idx ) const**

        Reimplements: **QAbstractItemModel::sibling(int row, int column, const
        QModelIndex &index) const** .
        """
        ...

    def supportedDropActions(self) -> Qt.DropAction:
        """
        https://doc.qt.io/qt-6/qabstractproxymodel.html#supportedDropActions

        **[override virtual] Qt::DropActions
        QAbstractProxyModel::supportedDropActions() const**

        Reimplements: **QAbstractItemModel::supportedDropActions() const** .
        """
        ...

    def mimeTypes(self) -> typing.List[str]:
        """
        https://doc.qt.io/qt-6/qabstractproxymodel.html#mimeTypes

        **[override virtual] QStringList QAbstractProxyModel::mimeTypes()
        const**

        Reimplements: **QAbstractItemModel::mimeTypes() const** .
        """
        ...

    def mimeData(self, indexes: typing.Iterable[QModelIndex]) -> "QMimeData":
        """
        https://doc.qt.io/qt-6/qabstractproxymodel.html#mimeData

        **[override virtual] QMimeData *QAbstractProxyModel::mimeData(const
        QModelIndexList & indexes ) const**

        Reimplements: **QAbstractItemModel::mimeData(const QModelIndexList
        &indexes) const** .
        """
        ...

    def hasChildren(self, parent: QModelIndex = ...) -> bool:
        """
        https://doc.qt.io/qt-6/qabstractproxymodel.html#hasChildren

        **[override virtual] bool QAbstractProxyModel::hasChildren(const
        QModelIndex & parent = QModelIndex()) const**

        Reimplements: **QAbstractItemModel::hasChildren(const QModelIndex
        &parent) const** .
        """
        ...

    def span(self, index: QModelIndex) -> "QSize":
        """
        https://doc.qt.io/qt-6/qabstractproxymodel.html#span

        **[override virtual] QSize QAbstractProxyModel::span(const QModelIndex &
        index ) const**

        Reimplements: **QAbstractItemModel::span(const QModelIndex &index)
        const** .
        """
        ...

    def sort(self, column: int, order: Qt.SortOrder = ...) -> None:
        """
        https://doc.qt.io/qt-6/qabstractproxymodel.html#sort

        **[override virtual] void QAbstractProxyModel::sort(int column ,
        Qt::SortOrder order = Qt::AscendingOrder)**

        Reimplements: **QAbstractItemModel::sort** (int column, Qt::SortOrder
        order).
        """
        ...

    def fetchMore(self, parent: QModelIndex) -> None:
        """
        https://doc.qt.io/qt-6/qabstractproxymodel.html#fetchMore

        **[override virtual] void QAbstractProxyModel::fetchMore(const
        QModelIndex & parent )**

        Reimplements: **QAbstractItemModel::fetchMore** (const QModelIndex
        &parent).
        """
        ...

    def canFetchMore(self, parent: QModelIndex) -> bool:
        """
        https://doc.qt.io/qt-6/qabstractproxymodel.html#canFetchMore

        **[override virtual] bool QAbstractProxyModel::canFetchMore(const
        QModelIndex & parent ) const**

        Reimplements: **QAbstractItemModel::canFetchMore(const QModelIndex
        &parent) const** .
        """
        ...

    def buddy(self, index: QModelIndex) -> QModelIndex:
        """
        https://doc.qt.io/qt-6/qabstractproxymodel.html#buddy

        **[override virtual] QModelIndex QAbstractProxyModel::buddy(const
        QModelIndex & index ) const**

        Reimplements: **QAbstractItemModel::buddy(const QModelIndex &index)
        const** .
        """
        ...

    def setItemData(
        self, index: QModelIndex, roles: typing.Dict[int, typing.Any]
    ) -> bool:
        """
        https://doc.qt.io/qt-6/qabstractproxymodel.html#setItemData

        **[override virtual] bool QAbstractProxyModel::setItemData(const
        QModelIndex & index , const QMap<int, QVariant> & roles )**

        Reimplements: **QAbstractItemModel::setItemData** (const QModelIndex
        &index, const QMap<int, QVariant> &roles).

        **See also** **itemData** ().
        """
        ...

    def flags(self, index: QModelIndex) -> Qt.ItemFlag:
        """
        https://doc.qt.io/qt-6/qabstractproxymodel.html#flags

        **[override virtual] Qt::ItemFlags QAbstractProxyModel::flags(const
        QModelIndex & index ) const**

        Reimplements: **QAbstractItemModel::flags(const QModelIndex &index)
        const** .
        """
        ...

    def itemData(self, index: QModelIndex) -> typing.Dict[int, typing.Any]:
        """
        https://doc.qt.io/qt-6/qabstractproxymodel.html#itemData

        **[override virtual] QMap<int, QVariant>
        QAbstractProxyModel::itemData(const QModelIndex & proxyIndex ) const**

        Reimplements: **QAbstractItemModel::itemData(const QModelIndex &index)
        const** .

        **See also** **setItemData** ().
        """
        ...

    def setHeaderData(
        self,
        section: int,
        orientation: Qt.Orientation,
        value: typing.Any,
        role: int = ...,
    ) -> bool:
        """
        https://doc.qt.io/qt-6/qabstractproxymodel.html#setHeaderData

        **[override virtual] bool QAbstractProxyModel::setHeaderData(int section
        , Qt::Orientation orientation , const QVariant & value , int role =
        Qt::EditRole)**

        Reimplements: **QAbstractItemModel::setHeaderData** (int section,
        Qt::Orientation orientation, const QVariant &value, int role).

        **See also** **headerData** ().
        """
        ...

    def headerData(
        self, section: int, orientation: Qt.Orientation, role: int = ...
    ) -> typing.Any:
        """
        https://doc.qt.io/qt-6/qabstractproxymodel.html#headerData

        **[override virtual] QVariant QAbstractProxyModel::headerData(int
        section , Qt::Orientation orientation , int role = Qt::DisplayRole)
        const**

        Reimplements: **QAbstractItemModel::headerData(int section,
        Qt::Orientation orientation, int role) const** .

        **See also** **setHeaderData** ().
        """
        ...

    def setData(self, index: QModelIndex, value: typing.Any, role: int = ...) -> bool:
        """
        https://doc.qt.io/qt-6/qabstractproxymodel.html#setData

        **[override virtual] bool QAbstractProxyModel::setData(const QModelIndex
        & index , const QVariant & value , int role = Qt::EditRole)**

        Reimplements: **QAbstractItemModel::setData** (const QModelIndex &index,
        const QVariant &value, int role).

        **See also** **data** ().
        """
        ...

    def data(self, proxyIndex: QModelIndex, role: int = ...) -> typing.Any:
        """
        https://doc.qt.io/qt-6/qabstractproxymodel.html#data

        **[override virtual] QVariant QAbstractProxyModel::data(const
        QModelIndex & proxyIndex , int role = Qt::DisplayRole) const**

        Reimplements: **QAbstractItemModel::data(const QModelIndex &index, int
        role) const** .

        **See also** **setData** ().
        """
        ...

    def revert(self) -> None:
        """
        https://doc.qt.io/qt-6/qabstractproxymodel.html#revert

        **[override virtual] void QAbstractProxyModel::revert()**

        Reimplements: **QAbstractItemModel::revert** ().
        """
        ...

    def submit(self) -> bool:
        """
        https://doc.qt.io/qt-6/qabstractproxymodel.html#submit

        **[override virtual] bool QAbstractProxyModel::submit()**

        Reimplements: **QAbstractItemModel::submit** ().
        """
        ...

    def mapSelectionFromSource(self, selection: "QItemSelection") -> "QItemSelection":
        """
        https://doc.qt.io/qt-6/qabstractproxymodel.html#mapSelectionFromSource

        **[virtual invokable] QItemSelection
        QAbstractProxyModel::mapSelectionFromSource(const QItemSelection &
        sourceSelection ) const**

        Returns a proxy selection mapped from the specified **sourceSelection**.

        Reimplement this method to map source selections to proxy selections.

        **Note:** This function can be invoked via the meta-object system and
        from QML. See **Q_INVOKABLE** .
        """
        ...

    def mapSelectionToSource(self, selection: "QItemSelection") -> "QItemSelection":
        """
        https://doc.qt.io/qt-6/qabstractproxymodel.html#mapSelectionToSource

        **[virtual invokable] QItemSelection
        QAbstractProxyModel::mapSelectionToSource(const QItemSelection &
        proxySelection ) const**

        Returns a source selection mapped from the specified **proxySelection**.

        Reimplement this method to map proxy selections to source selections.

        **Note:** This function can be invoked via the meta-object system and
        from QML. See **Q_INVOKABLE** .
        """
        ...

    def mapFromSource(self, sourceIndex: QModelIndex) -> QModelIndex:
        """
        https://doc.qt.io/qt-6/qabstractproxymodel.html#mapFromSource

        **[pure virtual invokable] QModelIndex
        QAbstractProxyModel::mapFromSource(const QModelIndex & sourceIndex )
        const**

        Reimplement this function to return the model index in the proxy model
        that corresponds to the **sourceIndex** from the source model.

        **Note:** This function can be invoked via the meta-object system and
        from QML. See **Q_INVOKABLE** .

        **See also** **mapToSource** ().
        """
        ...

    def mapToSource(self, proxyIndex: QModelIndex) -> QModelIndex:
        """
        https://doc.qt.io/qt-6/qabstractproxymodel.html#mapToSource

        **[pure virtual invokable] QModelIndex
        QAbstractProxyModel::mapToSource(const QModelIndex & proxyIndex )
        const**

        Reimplement this function to return the model index in the source model
        that corresponds to the **proxyIndex** in the proxy model.

        **Note:** This function can be invoked via the meta-object system and
        from QML. See **Q_INVOKABLE** .

        **See also** **mapFromSource** ().
        """
        ...

    def sourceModel(self) -> QAbstractItemModel:
        """
        https://doc.qt.io/qt-6/qabstractproxymodel.html#sourceModel

        **QAbstractItemModel *QAbstractProxyModel::sourceModel() const**

        Returns the model that contains the data that is available through the
        proxy model.

        **Note:** Getter function for property sourceModel.

        **See also** **setSourceModel** ().
        """
        ...

    def setSourceModel(self, sourceModel: QAbstractItemModel) -> None:
        """
        https://doc.qt.io/qt-6/qabstractproxymodel.html#setSourceModel

        **[virtual] void QAbstractProxyModel::setSourceModel(QAbstractItemModel
        * sourceModel )**

        Sets the given **sourceModel** to be processed by the proxy model.

        Subclasses should call **beginResetModel** () at the beginning of the
        method, disconnect from the old model, call this method, connect to the
        new model, and call **endResetModel** ().

        **Note:** Setter function for property **sourceModel** .

        **See also** **sourceModel** ().
        """
        ...

    @property
    def sourceModelChanged(self) -> PyQt6.QtCore.pyqtBoundSignal:
        ...



"""
PySide stub files generated by **IceSpringPySideStubs**

Home: https://baijifeilong.github.io/2022/01/06/ice-spring-pyside-stubs/index.html

Github: https://github.com/baijifeilong/IceSpringPySideStubs

PyPI(PySide2): https://pypi.org/project/IceSpringPySideStubs-PySide2

PyPI(PySide6): https://pypi.org/project/IceSpringPySideStubs-PySide6

PyPI(PyQt5): https://pypi.org/project/IceSpringPySideStubs-PyQt5

PyPI(PyQt6): https://pypi.org/project/IceSpringPySideStubs-PyQt6

Generated by BaiJiFeiLong@gmail.com

License: MIT
"""
import typing
from PyQt6 import QtCore
from PyQt6.QtSql import *


class QSqlQueryModel(QtCore.QAbstractTableModel):
    """
    https://doc.qt.io/qt-6/qsqlquerymodel.html

    **Detailed Description**

    QSqlQueryModel is a high-level interface for executing SQL statements and
    traversing the result set. It is built on top of the lower-level
    **QSqlQuery**  and can be used to provide data to view classes such as
    **QTableView** . For example:

    **QSqlQueryModel**  *model = new **QSqlQueryModel** ;
    model->setQuery("SELECT name, salary FROM employee");
    model->setHeaderData(0, Qt::Horizontal, tr("Name"));
    model->setHeaderData(1, Qt::Horizontal, tr("Salary"));
    **QTableView**  *view = new **QTableView** ;
            view->setModel(model);
    view->show();

    We set the model's query, then we set up the labels displayed in the view
    header.

    QSqlQueryModel can also be used to access a database programmatically,
    without binding it to a view:

    **QSqlQueryModel**  model;
            model.setQuery("SELECT name, salary FROM
    employee");
            int salary = model.record(4).value("salary").toInt();

    The code snippet above extracts the `salary` field from record 4 in the
    result set of the `SELECT` query. Since `salary` is the 2nd column (or
    column index 1), we can rewrite the last line as follows:

    int salary = model.data(model.index(4, 1)).toInt();

    The model is read-only by default. To make it read-write, you must subclass
    it and reimplement **setData** () and **flags** (). Another option is to use
    **QSqlTableModel** , which provides a read-write model based on a single
    database table.

    The **querymodel**  example illustrates how to use QSqlQueryModel to display
    the result of a query. It also shows how to subclass QSqlQueryModel to
    customize the contents of the data before showing it to the user, and how to
    create a read-write model based on QSqlQueryModel.

    If the database doesn't return the number of selected rows in a query, the
    model will fetch rows incrementally. See **fetchMore** () for more
    information.

    **See also** **QSqlTableModel** , **QSqlRelationalTableModel** ,
    **QSqlQuery** , **Model/View Programming** , and **Query Model Example** .
    """

    def __init__(self, parent: typing.Optional[QtCore.QObject] = ...) -> None:
        """
        https://doc.qt.io/qt-6/qsqlquerymodel.html#QSqlQueryModel

        **QSqlQueryModel::QSqlQueryModel(QObject * parent = nullptr)**

        Creates an empty QSqlQueryModel with the given **parent**.
        """
        ...

    def roleNames(self) -> typing.Dict[int, QtCore.QByteArray]:
        """
        https://doc.qt.io/qt-6/qsqlquerymodel.html#roleNames

        **[override virtual, since 5.10] QHash<int, QByteArray>
        QSqlQueryModel::roleNames() const**

        Reimplements: **QAbstractItemModel::roleNames() const** .

        Returns the model's role names.

        Qt defines only one role for the **QSqlQueryModel** :

        Qt RoleQML Role Name
        **Qt::DisplayRole** display

        This function was introduced in Qt 5.10.
        """
        ...

    def endRemoveColumns(self) -> None:
        ...

    def beginRemoveColumns(
        self, parent: QtCore.QModelIndex, first: int, last: int
    ) -> None:
        ...

    def endInsertColumns(self) -> None:
        ...

    def beginInsertColumns(
        self, parent: QtCore.QModelIndex, first: int, last: int
    ) -> None:
        ...

    def endRemoveRows(self) -> None:
        ...

    def beginRemoveRows(
        self, parent: QtCore.QModelIndex, first: int, last: int
    ) -> None:
        ...

    def endInsertRows(self) -> None:
        ...

    def beginInsertRows(
        self, parent: QtCore.QModelIndex, first: int, last: int
    ) -> None:
        ...

    def endResetModel(self) -> None:
        ...

    def beginResetModel(self) -> None:
        ...

    def setLastError(self, error: QSqlError) -> None:
        """
        https://doc.qt.io/qt-6/qsqlquerymodel.html#setLastError

        **[protected] void QSqlQueryModel::setLastError(const QSqlError & error
        )**

        Protected function which allows derived classes to set the value of the
        last error that occurred on the database to **error**.

        **See also** **lastError** ().
        """
        ...

    def indexInQuery(self, item: QtCore.QModelIndex) -> QtCore.QModelIndex:
        """
        https://doc.qt.io/qt-6/qsqlquerymodel.html#indexInQuery

        **[virtual protected] QModelIndex QSqlQueryModel::indexInQuery(const
        QModelIndex & item ) const**

        Returns the index of the value in the database result set for the given
        **item** in the model.

        The return value is identical to **item** if no columns or rows have
        been inserted, removed, or moved around.

        Returns an invalid model index if **item** is out of bounds or if
        **item** does not point to a value in the result set.

        **See also** **QSqlTableModel::indexInQuery** (), **insertColumns** (),
        and **removeColumns** ().
        """
        ...

    def queryChange(self) -> None:
        """
        https://doc.qt.io/qt-6/qsqlquerymodel.html#queryChange

        **[virtual protected] void QSqlQueryModel::queryChange()**

        This virtual function is called whenever the query changes. The default
        implementation does nothing.

        **query** () returns the new query.

        **See also** **query** () and **setQuery** ().
        """
        ...

    def canFetchMore(self, parent: QtCore.QModelIndex = ...) -> bool:
        """
        https://doc.qt.io/qt-6/qsqlquerymodel.html#canFetchMore

        **[override virtual] bool QSqlQueryModel::canFetchMore(const QModelIndex
        & parent = QModelIndex()) const**

        Reimplements: **QAbstractItemModel::canFetchMore(const QModelIndex
        &parent) const** .

        Returns `true` if it is possible to read more rows from the database.
        This only affects databases that don't report back the size of a query
        (see **QSqlDriver::hasFeature** ()).

        **parent** should always be an invalid **QModelIndex** .

        **See also** **fetchMore** ().
        """
        ...

    def fetchMore(self, parent: QtCore.QModelIndex = ...) -> None:
        """
        https://doc.qt.io/qt-6/qsqlquerymodel.html#fetchMore

        **[override virtual] void QSqlQueryModel::fetchMore(const QModelIndex &
        parent = QModelIndex())**

        Reimplements: **QAbstractItemModel::fetchMore** (const QModelIndex
        &parent).

        Fetches more rows from a database. This only affects databases that
        don't report back the size of a query (see **QSqlDriver::hasFeature**
        ()).

        To force fetching of the entire result set, you can use the following:

        while (myModel->canFetchMore())
                myModel->fetchMore();

        **parent** should always be an invalid **QModelIndex** .

        **See also** **canFetchMore** ().
        """
        ...

    def lastError(self) -> QSqlError:
        """
        https://doc.qt.io/qt-6/qsqlquerymodel.html#lastError

        **QSqlError QSqlQueryModel::lastError() const**

        Returns information about the last error that occurred on the database.

        **See also** **setLastError** () and **query** ().
        """
        ...

    def clear(self) -> None:
        """
        https://doc.qt.io/qt-6/qsqlquerymodel.html#clear

        **[virtual] void QSqlQueryModel::clear()**

        Clears the model and releases any acquired resource.
        """
        ...

    def query(self) -> QSqlQuery:
        """
        https://doc.qt.io/qt-6/qsqlquerymodel.html#query

        **QSqlQuery QSqlQueryModel::query() const**

        Returns the **QSqlQuery**  associated with this model.

        **See also** **setQuery** ().
        """
        ...

    @typing.overload
    def setQuery(self, query: QSqlQuery) -> None:
        """
        https://doc.qt.io/qt-6/qsqlquerymodel.html#setQuery

        **[since 6.2] void QSqlQueryModel::setQuery(QSqlQuery && query )**

        Resets the model and sets the data provider to be the given **query**.
        Note that the query must be active and must not be isForwardOnly().

        **lastError** () can be used to retrieve verbose information if there
        was an error setting the query.

        **Note:** Calling setQuery() will remove any inserted columns.

        This function was introduced in Qt 6.2.

        **See also** **query** (), **QSqlQuery::isActive** (),
        **QSqlQuery::setForwardOnly** (), and **lastError** ().
        """
        ...

    @typing.overload
    def setQuery(self, query: str, db: QSqlDatabase = ...) -> None:
        """
        https://doc.qt.io/qt-6/qsqlquerymodel.html#setQuery-2

        **void QSqlQueryModel::setQuery(const QString & query , const
        QSqlDatabase & db = QSqlDatabase())**

        This is an overloaded function.

        Executes the query **query** for the given database connection **db**.
        If no database (or an invalid database) is specified, the default
        connection is used.

        **lastError** () can be used to retrieve verbose information if there
        was an error setting the query.

        Example:

        **QSqlQueryModel**  model;
            model.setQuery("select * from MyTable");
        if (model.lastError().isValid())
                **qDebug** () <<
        model.lastError();

        **See also** **query** (), **queryChange** (), and **lastError** ().
        """
        ...

    def removeColumns(
        self, column: int, count: int, parent: QtCore.QModelIndex = ...
    ) -> bool:
        """
        https://doc.qt.io/qt-6/qsqlquerymodel.html#removeColumns

        **[override virtual] bool QSqlQueryModel::removeColumns(int column , int
        count , const QModelIndex & parent = QModelIndex())**

        Reimplements: **QAbstractItemModel::removeColumns** (int column, int
        count, const QModelIndex &parent).

        Removes **count** columns from the model starting from position
        **column**. The **parent** parameter must always be an invalid
        **QModelIndex** , since the model does not support parent-child
        relationships.

        Removing columns effectively hides them. It does not affect the
        underlying **QSqlQuery** .

        Returns `true` if the columns were removed; otherwise returns `false`.
        """
        ...

    def insertColumns(
        self, column: int, count: int, parent: QtCore.QModelIndex = ...
    ) -> bool:
        """
        https://doc.qt.io/qt-6/qsqlquerymodel.html#insertColumns

        **[override virtual] bool QSqlQueryModel::insertColumns(int column , int
        count , const QModelIndex & parent = QModelIndex())**

        Reimplements: **QAbstractItemModel::insertColumns** (int column, int
        count, const QModelIndex &parent).

        Inserts **count** columns into the model at position **column**. The
        **parent** parameter must always be an invalid **QModelIndex** , since
        the model does not support parent-child relationships.

        Returns `true` if **column** is within bounds; otherwise returns
        `false`.

        By default, inserted columns are empty. To fill them with data,
        reimplement **data** () and handle any inserted column separately:

        **QVariant**  MyModel::data(const **QModelIndex**  &item, int role)
        const
            {
                if (item.column() == m_specialColumnNo) {
        // handle column separately
                }
                return **QSqlQueryModel**
        ::data(item, role);
            }

        **See also** **removeColumns** ().
        """
        ...

    def setHeaderData(
        self,
        section: int,
        orientation: QtCore.Qt.Orientation,
        value: typing.Any,
        role: int = ...,
    ) -> bool:
        """
        https://doc.qt.io/qt-6/qsqlquerymodel.html#setHeaderData

        **[override virtual] bool QSqlQueryModel::setHeaderData(int section ,
        Qt::Orientation orientation , const QVariant & value , int role =
        Qt::EditRole)**

        Reimplements: **QAbstractItemModel::setHeaderData** (int section,
        Qt::Orientation orientation, const QVariant &value, int role).

        Sets the caption for a horizontal header for the specified **role** to
        **value**. This is useful if the model is used to display data in a view
        (e.g., **QTableView** ).

        Returns `true` if **orientation** is **Qt::Horizontal**  and the
        **section** refers to a valid section; otherwise returns false.

        Note that this function cannot be used to modify values in the database
        since the model is read-only.

        **See also** **headerData** () and **data** ().
        """
        ...

    def headerData(
        self, section: int, orientation: QtCore.Qt.Orientation, role: int = ...
    ) -> typing.Any:
        """
        https://doc.qt.io/qt-6/qsqlquerymodel.html#headerData

        **[override virtual] QVariant QSqlQueryModel::headerData(int section ,
        Qt::Orientation orientation , int role = Qt::DisplayRole) const**

        Reimplements: **QAbstractItemModel::headerData(int section,
        Qt::Orientation orientation, int role) const** .

        Returns the header data for the given **role** in the **section** of the
        header with the specified **orientation**.

        **See also** **setHeaderData** ().
        """
        ...

    def data(self, item: QtCore.QModelIndex, role: int = ...) -> typing.Any:
        """
        https://doc.qt.io/qt-6/qsqlquerymodel.html#data

        **[override virtual] QVariant QSqlQueryModel::data(const QModelIndex &
        item , int role = Qt::DisplayRole) const**

        Reimplements: **QAbstractItemModel::data(const QModelIndex &index, int
        role) const** .

        Returns the value for the specified **item** and **role**.

        If **item** is out of bounds or if an error occurred, an invalid
        **QVariant**  is returned.

        **See also** **lastError** ().
        """
        ...

    @typing.overload
    def record(self) -> QSqlRecord:
        """
        https://doc.qt.io/qt-6/qsqlquerymodel.html#record

        **QSqlRecord QSqlQueryModel::record(int row ) const**

        Returns the record containing information about the fields of the
        current query. If **row** is the index of a valid row, the record will
        be populated with values from that row.

        If the model is not initialized, an empty record will be returned.

        **See also** **QSqlRecord::isEmpty** ().
        """
        ...

    @typing.overload
    def record(self, row: int) -> QSqlRecord:
        """
        https://doc.qt.io/qt-6/qsqlquerymodel.html#record-1

        **QSqlRecord QSqlQueryModel::record() const**

        This is an overloaded function.

        Returns an empty record containing information about the fields of the
        current query.

        If the model is not initialized, an empty record will be returned.

        **See also** **QSqlRecord::isEmpty** ().
        """
        ...

    def columnCount(self, parent: QtCore.QModelIndex = ...) -> int:
        """
        https://doc.qt.io/qt-6/qsqlquerymodel.html#columnCount

        **[override virtual] int QSqlQueryModel::columnCount(const QModelIndex &
        index = QModelIndex()) const**

        Reimplements: **QAbstractItemModel::columnCount(const QModelIndex
        &parent) const** .
        """
        ...

    def rowCount(self, parent: QtCore.QModelIndex = ...) -> int:
        """
        https://doc.qt.io/qt-6/qsqlquerymodel.html#rowCount

        **[override virtual] int QSqlQueryModel::rowCount(const QModelIndex &
        parent = QModelIndex()) const**

        Reimplements: **QAbstractItemModel::rowCount(const QModelIndex &parent)
        const** .

        If the database supports returning the size of a query (see
        **QSqlDriver::hasFeature** ()), the number of rows of the current query
        is returned. Otherwise, returns the number of rows currently cached on
        the client.

        **parent** should always be an invalid **QModelIndex** .

        **See also** **canFetchMore** () and **QSqlDriver::hasFeature** ().
        """
        ...



"""
PySide stub files generated by **IceSpringPySideStubs**

Home: https://baijifeilong.github.io/2022/01/06/ice-spring-pyside-stubs/index.html

Github: https://github.com/baijifeilong/IceSpringPySideStubs

PyPI(PySide2): https://pypi.org/project/IceSpringPySideStubs-PySide2

PyPI(PySide6): https://pypi.org/project/IceSpringPySideStubs-PySide6

PyPI(PyQt5): https://pypi.org/project/IceSpringPySideStubs-PyQt5

PyPI(PyQt6): https://pypi.org/project/IceSpringPySideStubs-PyQt6

Generated by BaiJiFeiLong@gmail.com

License: MIT
"""
import enum
import typing
import PyQt6.sip
from PyQt6 import QtCore
from PyQt6.QtGui import *
import enum


class QTextLine(PyQt6.sip.simplewrapper):
    """
    https://doc.qt.io/qt-6/qtextline.html

    **Detailed Description**

    A text line is usually created by **QTextLayout::createLine** ().

    After being created, the line can be filled using the **setLineWidth** () or
    **setNumColumns** () functions. A line has a number of attributes including
    the rectangle it occupies, **rect** (), its coordinates, **x** () and **y**
    (), its **textLength** (), **width** () and **naturalTextWidth** (), and its
    **ascent** () and **descent** () relative to the text. The position of the
    cursor in terms of the line is available from **cursorToX** () and its
    inverse from **xToCursor** (). A line can be moved with **setPosition** ().
    """

    class CursorPosition(enum.Enum):
        CursorBetweenCharacters: QTextLine = ...
        CursorOnCharacter: QTextLine = ...

    class Edge(enum.Enum):
        Leading: QTextLine = ...
        Trailing: QTextLine = ...

    @typing.overload
    def __init__(self) -> None:
        """
        https://doc.qt.io/qt-6/qtextline.html#QTextLine

        **QTextLine::QTextLine()**

        Creates an invalid line.
        """
        ...

    @typing.overload
    def __init__(self, a0: "QTextLine") -> None:
        """
        https://doc.qt.io/qt-6/qtextline.html#QTextLine

        **QTextLine::QTextLine()**

        Creates an invalid line.
        """
        ...

    def glyphRuns(self, from_: int = ..., length: int = ...) -> typing.List[QGlyphRun]:
        """
        https://doc.qt.io/qt-6/qtextline.html#glyphRuns

        **[since 5.0] QList<QGlyphRun> QTextLine::glyphRuns(int from = -1, int
        length = -1) const**

        Returns the glyph indexes and positions for all glyphs in this
        **QTextLine**  for characters in the range defined by **from** and
        **length**. The **from** index is relative to the beginning of the text
        in the containing **QTextLayout** , and the range must be within the
        range of **QTextLine**  as given by functions **textStart** () and
        **textLength** ().

        If **from** is negative, it will default to **textStart** (), and if
        **length** is negative it will default to the return value of
        **textLength** ().

        This function was introduced in Qt 5.0.

        **See also** **QTextLayout::glyphRuns** ().
        """
        ...

    def horizontalAdvance(self) -> float:
        """
        https://doc.qt.io/qt-6/qtextline.html#horizontalAdvance

        **qreal QTextLine::horizontalAdvance() const**

        Returns the horizontal advance of the text. The advance of the text is
        the distance from its position to the next position at which text would
        naturally be drawn.

        By adding the advance to the position of the text line and using this as
        the position of a second text line, you will be able to position the two
        lines side-by-side without gaps in-between.
        """
        ...

    def leadingIncluded(self) -> bool:
        """
        https://doc.qt.io/qt-6/qtextline.html#leadingIncluded

        **bool QTextLine::leadingIncluded() const**

        Returns `true` if positive leading is included into the line's height;
        otherwise returns `false`.

        By default, leading is not included.

        **See also** **setLeadingIncluded** ().
        """
        ...

    def setLeadingIncluded(self, included: bool) -> None:
        """
        https://doc.qt.io/qt-6/qtextline.html#setLeadingIncluded

        **void QTextLine::setLeadingIncluded(bool included )**

        Includes positive leading into the line's height if **included** is
        true; otherwise does not include leading.

        By default, leading is not included.

        Note that negative leading is ignored, it must be handled in the code
        using the text lines by letting the lines overlap.

        **See also** **leadingIncluded** ().
        """
        ...

    def leading(self) -> float:
        """
        https://doc.qt.io/qt-6/qtextline.html#leading

        **qreal QTextLine::leading() const**

        Returns the line's leading.

        **See also** **ascent** (), **descent** (), and **height** ().
        """
        ...

    def position(self) -> QtCore.QPointF:
        """
        https://doc.qt.io/qt-6/qtextline.html#position

        **QPointF QTextLine::position() const**

        Returns the line's position relative to the text layout's position.

        **See also** **setPosition** ().
        """
        ...

    def draw(self, painter: QPainter, position: QtCore.QPointF) -> None:
        """
        https://doc.qt.io/qt-6/qtextline.html#draw

        **void QTextLine::draw(QPainter * painter , const QPointF & position )
        const**

        Draws a line on the given **painter** at the specified **position**.
        """
        ...

    def lineNumber(self) -> int:
        """
        https://doc.qt.io/qt-6/qtextline.html#lineNumber

        **int QTextLine::lineNumber() const**

        Returns the position of the line in the text engine.
        """
        ...

    def textLength(self) -> int:
        """
        https://doc.qt.io/qt-6/qtextline.html#textLength

        **int QTextLine::textLength() const**

        Returns the length of the text in the line.

        **See also** **naturalTextWidth** ().
        """
        ...

    def textStart(self) -> int:
        """
        https://doc.qt.io/qt-6/qtextline.html#textStart

        **int QTextLine::textStart() const**

        Returns the start of the line from the beginning of the string passed to
        the **QTextLayout** .
        """
        ...

    def setPosition(self, pos: QtCore.QPointF) -> None:
        """
        https://doc.qt.io/qt-6/qtextline.html#setPosition

        **void QTextLine::setPosition(const QPointF & pos )**

        Moves the line to position **pos**.

        **See also** **position** ().
        """
        ...

    @typing.overload
    def setNumColumns(self, columns: int) -> None:
        """
        https://doc.qt.io/qt-6/qtextline.html#setNumColumns

        **void QTextLine::setNumColumns(int numColumns )**

        Lays out the line. The line is filled from its starting position with as
        many characters as are specified by **numColumns**. In case the text
        cannot be split until **numColumns** characters, the line will be filled
        with as many characters to the next whitespace or end of the text.
        """
        ...

    @typing.overload
    def setNumColumns(self, columns: int, alignmentWidth: float) -> None:
        """
        https://doc.qt.io/qt-6/qtextline.html#setNumColumns-1

        **void QTextLine::setNumColumns(int numColumns , qreal alignmentWidth
        )**

        Lays out the line. The line is filled from its starting position with as
        many characters as are specified by **numColumns**. In case the text
        cannot be split until **numColumns** characters, the line will be filled
        with as many characters to the next whitespace or end of the text. The
        provided **alignmentWidth** is used as reference width for alignment.
        """
        ...

    def setLineWidth(self, width: float) -> None:
        """
        https://doc.qt.io/qt-6/qtextline.html#setLineWidth

        **void QTextLine::setLineWidth(qreal width )**

        Lays out the line with the given **width**. The line is filled from its
        starting position with as many characters as will fit into the line. In
        case the text cannot be split at the end of the line, it will be filled
        with additional characters to the next whitespace or end of the text.
        """
        ...

    def xToCursor(self, x: float, edge: "QTextLine.CursorPosition" = ...) -> int:
        """
        https://doc.qt.io/qt-6/qtextline.html#xToCursor

        **int QTextLine::xToCursor(qreal x , QTextLine::CursorPosition cpos =
        CursorBetweenCharacters) const**

        Converts the x-coordinate **x** , to the nearest matching cursor
        position, depending on the cursor position type, **cpos**. Note that
        result cursor position includes possible preedit area text.

        **See also** **cursorToX** ().
        """
        ...

    def cursorToX(
        self, cursorPos: int, edge: "QTextLine.Edge" = ...
    ) -> typing.Tuple[float, int]:
        """
        https://doc.qt.io/qt-6/qtextline.html#cursorToX

        **qreal QTextLine::cursorToX(int * cursorPos , QTextLine::Edge edge =
        Leading) const**

        Converts the cursor position **cursorPos** to the corresponding x
        position inside the line, taking account of the **edge**.

        If **cursorPos** is not a valid cursor position, the nearest valid
        cursor position will be used instead, and **cursorPos** will be modified
        to point to this valid cursor position.

        **See also** **xToCursor** ().
        """
        ...

    def naturalTextRect(self) -> QtCore.QRectF:
        """
        https://doc.qt.io/qt-6/qtextline.html#naturalTextRect

        **QRectF QTextLine::naturalTextRect() const**

        Returns the rectangle covered by the line.
        """
        ...

    def naturalTextWidth(self) -> float:
        """
        https://doc.qt.io/qt-6/qtextline.html#naturalTextWidth

        **qreal QTextLine::naturalTextWidth() const**

        Returns the width of the line that is occupied by text. This is always
        <= to **width** (), and is the minimum width that could be used by
        layout() without changing the line break position.
        """
        ...

    def height(self) -> float:
        """
        https://doc.qt.io/qt-6/qtextline.html#height

        **qreal QTextLine::height() const**

        Returns the line's height. This is equal to **ascent** () + **descent**
        () if leading is not included. If leading is included, this equals to
        **ascent** () + **descent** () + **leading** ().

        **See also** **ascent** (), **descent** (), **leading** (), and
        **setLeadingIncluded** ().
        """
        ...

    def descent(self) -> float:
        """
        https://doc.qt.io/qt-6/qtextline.html#descent

        **qreal QTextLine::descent() const**

        Returns the line's descent.

        **See also** **ascent** () and **height** ().
        """
        ...

    def ascent(self) -> float:
        """
        https://doc.qt.io/qt-6/qtextline.html#ascent

        **qreal QTextLine::ascent() const**

        Returns the line's ascent.

        **See also** **descent** () and **height** ().
        """
        ...

    def width(self) -> float:
        """
        https://doc.qt.io/qt-6/qtextline.html#width

        **qreal QTextLine::width() const**

        Returns the line's width as specified by the layout() function.

        **See also** **naturalTextWidth** (), **x** (), **y** (), **textLength**
        (), and **rect** ().
        """
        ...

    def y(self) -> float:
        """
        https://doc.qt.io/qt-6/qtextline.html#y

        **qreal QTextLine::y() const**

        Returns the line's y position.

        **See also** **x** (), **rect** (), **textLength** (), and **width** ().
        """
        ...

    def x(self) -> float:
        """
        https://doc.qt.io/qt-6/qtextline.html#x

        **qreal QTextLine::x() const**

        Returns the line's x position.

        **See also** **rect** (), **y** (), **textLength** (), and **width** ().
        """
        ...

    def rect(self) -> QtCore.QRectF:
        """
        https://doc.qt.io/qt-6/qtextline.html#rect

        **QRectF QTextLine::rect() const**

        Returns the line's bounding rectangle.

        **See also** **x** (), **y** (), **textLength** (), and **width** ().
        """
        ...

    def isValid(self) -> bool:
        """
        https://doc.qt.io/qt-6/qtextline.html#isValid

        **bool QTextLine::isValid() const**

        Returns `true` if this text line is valid; otherwise returns `false`.
        """
        ...



"""
PySide stub files generated by **IceSpringPySideStubs**

Home: https://baijifeilong.github.io/2022/01/06/ice-spring-pyside-stubs/index.html

Github: https://github.com/baijifeilong/IceSpringPySideStubs

PyPI(PySide2): https://pypi.org/project/IceSpringPySideStubs-PySide2

PyPI(PySide6): https://pypi.org/project/IceSpringPySideStubs-PySide6

PyPI(PyQt5): https://pypi.org/project/IceSpringPySideStubs-PyQt5

PyPI(PyQt6): https://pypi.org/project/IceSpringPySideStubs-PyQt6

Generated by BaiJiFeiLong@gmail.com

License: MIT
"""
import typing
import PyQt6.sip
from PyQt6 import QtCore
from PyQt6.QtGui import *


class QTextInlineObject(PyQt6.sip.simplewrapper):
    """
    https://doc.qt.io/qt-6/qtextinlineobject.html

    **Detailed Description**

    Normally, you do not need to create a QTextInlineObject. It is used by
    **QAbstractTextDocumentLayout**  to handle inline objects when implementing
    a custom layout.

    The inline object has various attributes that can be set, for example using,
    **setWidth** (), **setAscent** (), and **setDescent** (). The rectangle it
    occupies is given by **rect** (), and its direction by **textDirection** ().
    Its position in the text layout is given by **textPosition** (), and its
    format is given by **format** ().
    """

    @typing.overload
    def __init__(self) -> None:
        ...

    @typing.overload
    def __init__(self, a0: "QTextInlineObject") -> None:
        ...

    def format(self) -> QTextFormat:
        """
        https://doc.qt.io/qt-6/qtextinlineobject.html#format

        **QTextFormat QTextInlineObject::format() const**

        Returns format of the inline object within the text layout.
        """
        ...

    def formatIndex(self) -> int:
        """
        https://doc.qt.io/qt-6/qtextinlineobject.html#formatIndex

        **int QTextInlineObject::formatIndex() const**

        Returns an integer describing the format of the inline object within the
        text layout.
        """
        ...

    def textPosition(self) -> int:
        """
        https://doc.qt.io/qt-6/qtextinlineobject.html#textPosition

        **int QTextInlineObject::textPosition() const**

        The position of the inline object within the text layout.
        """
        ...

    def setDescent(self, d: float) -> None:
        """
        https://doc.qt.io/qt-6/qtextinlineobject.html#setDescent

        **void QTextInlineObject::setDescent(qreal d )**

        Sets the inline object's descent to **d**.

        **See also** **descent** (), **setAscent** (), **width** (), and
        **rect** ().
        """
        ...

    def setAscent(self, a: float) -> None:
        """
        https://doc.qt.io/qt-6/qtextinlineobject.html#setAscent

        **void QTextInlineObject::setAscent(qreal a )**

        Sets the inline object's ascent to **a**.

        **See also** **ascent** (), **setDescent** (), **width** (), and
        **rect** ().
        """
        ...

    def setWidth(self, w: float) -> None:
        """
        https://doc.qt.io/qt-6/qtextinlineobject.html#setWidth

        **void QTextInlineObject::setWidth(qreal w )**

        Sets the inline object's width to **w**.

        **See also** **width** (), **ascent** (), **descent** (), and **rect**
        ().
        """
        ...

    def textDirection(self) -> QtCore.Qt.LayoutDirection:
        """
        https://doc.qt.io/qt-6/qtextinlineobject.html#textDirection

        **Qt::LayoutDirection QTextInlineObject::textDirection() const**

        Returns if the object should be laid out right-to-left or left-to-right.
        """
        ...

    def height(self) -> float:
        """
        https://doc.qt.io/qt-6/qtextinlineobject.html#height

        **qreal QTextInlineObject::height() const**

        Returns the inline object's total height. This is equal to **ascent** ()
        + **descent** () + 1.

        **See also** **ascent** (), **descent** (), **width** (), and **rect**
        ().
        """
        ...

    def descent(self) -> float:
        """
        https://doc.qt.io/qt-6/qtextinlineobject.html#descent

        **qreal QTextInlineObject::descent() const**

        Returns the inline object's descent.

        **See also** **setDescent** (), **ascent** (), **width** (), and
        **rect** ().
        """
        ...

    def ascent(self) -> float:
        """
        https://doc.qt.io/qt-6/qtextinlineobject.html#ascent

        **qreal QTextInlineObject::ascent() const**

        Returns the inline object's ascent.

        **See also** **setAscent** (), **descent** (), **width** (), and
        **rect** ().
        """
        ...

    def width(self) -> float:
        """
        https://doc.qt.io/qt-6/qtextinlineobject.html#width

        **qreal QTextInlineObject::width() const**

        Returns the inline object's width.

        **See also** **setWidth** (), **ascent** (), **descent** (), and
        **rect** ().
        """
        ...

    def rect(self) -> QtCore.QRectF:
        """
        https://doc.qt.io/qt-6/qtextinlineobject.html#rect

        **QRectF QTextInlineObject::rect() const**

        Returns the inline object's rectangle.

        **See also** **ascent** (), **descent** (), and **width** ().
        """
        ...

    def isValid(self) -> bool:
        """
        https://doc.qt.io/qt-6/qtextinlineobject.html#isValid

        **bool QTextInlineObject::isValid() const**

        Returns `true` if this inline object is valid; otherwise returns false.
        """
        ...



"""
PySide stub files generated by **IceSpringPySideStubs**

Home: https://baijifeilong.github.io/2022/01/06/ice-spring-pyside-stubs/index.html

Github: https://github.com/baijifeilong/IceSpringPySideStubs

PyPI(PySide2): https://pypi.org/project/IceSpringPySideStubs-PySide2

PyPI(PySide6): https://pypi.org/project/IceSpringPySideStubs-PySide6

PyPI(PyQt5): https://pypi.org/project/IceSpringPySideStubs-PyQt5

PyPI(PyQt6): https://pypi.org/project/IceSpringPySideStubs-PyQt6

Generated by BaiJiFeiLong@gmail.com

License: MIT
"""
import typing
import PyQt6.sip
from PyQt6 import QtCore
from PyQt6.QtGui import *


class QTextDocumentWriter(PyQt6.sip.simplewrapper):
    """
    https://doc.qt.io/qt-6/qtextdocumentwriter.html

    **Detailed Description**

    To write a document, construct a QTextDocumentWriter object with either a
    file name or a device object, and specify the document format to be written.
    You can construct a writer and set the format using **setFormat** () later.

    Call **write** () to write the document to the device. If the document is
    successfully written, this function returns `true`. However, if an error
    occurs when writing the document, it will return false.

    Call **supportedDocumentFormats** () for a list of formats that
    QTextDocumentWriter can write.

    Since the capabilities of the supported output formats vary considerably,
    the writer simply outputs the appropriate subset of objects for each format.
    This typically includes the formatted text and images contained in a
    document.
    """

    @typing.overload
    def __init__(self) -> None:
        """
        https://doc.qt.io/qt-6/qtextdocumentwriter.html#QTextDocumentWriter

        **QTextDocumentWriter::QTextDocumentWriter()**

        Constructs an empty QTextDocumentWriter object. Before writing, you must
        call **setFormat** () to set a document format, then **setDevice** () or
        **setFileName** ().
        """
        ...

    @typing.overload
    def __init__(self, device: QtCore.QIODevice, format: QtCore.QByteArray) -> None:
        """
        https://doc.qt.io/qt-6/qtextdocumentwriter.html#QTextDocumentWriter-1

        **QTextDocumentWriter::QTextDocumentWriter(QIODevice * device , const
        QByteArray & format )**

        Constructs a QTextDocumentWriter object to write to the given **device**
        in the document format specified by **format**.
        """
        ...

    @typing.overload
    def __init__(self, fileName: str, format: QtCore.QByteArray = ...) -> None:
        """
        https://doc.qt.io/qt-6/qtextdocumentwriter.html#QTextDocumentWriter-2

        **QTextDocumentWriter::QTextDocumentWriter(const QString & fileName ,
        const QByteArray & format = QByteArray())**

        Constructs an QTextDocumentWriter object that will write to a file with
        the name **fileName** , using the document format specified by
        **format**. If **format** is not provided, QTextDocumentWriter will
        detect the document format by inspecting the extension of **fileName**.
        """
        ...

    @staticmethod
    def supportedDocumentFormats() -> typing.List[QtCore.QByteArray]:
        """
        https://doc.qt.io/qt-6/qtextdocumentwriter.html#supportedDocumentFormats

        **[static] QList<QByteArray>
        QTextDocumentWriter::supportedDocumentFormats()**

        Returns the list of document formats supported by
        **QTextDocumentWriter** .

        By default, Qt can write the following formats:

        FormatDescription
        plaintextPlain text
        HTMLHyperText Markup Language
        markdownMarkdown (CommonMark or GitHub dialects)
        ODFOpenDocument
        Format

        **See also** **setFormat** ().
        """
        ...

    @typing.overload
    def write(self, document: QTextDocument) -> bool:
        """
        https://doc.qt.io/qt-6/qtextdocumentwriter.html#write

        **bool QTextDocumentWriter::write(const QTextDocument * document )**

        Writes the given **document** to the assigned device or file and returns
        `true` if successful; otherwise returns `false`.
        """
        ...

    @typing.overload
    def write(self, fragment: QTextDocumentFragment) -> bool:
        """
        https://doc.qt.io/qt-6/qtextdocumentwriter.html#write-1

        **bool QTextDocumentWriter::write(const QTextDocumentFragment & fragment
        )**

        Writes the document fragment specified by **fragment** to the assigned
        device or file and returns `true` if successful; otherwise returns
        `false`.
        """
        ...

    def fileName(self) -> str:
        """
        https://doc.qt.io/qt-6/qtextdocumentwriter.html#fileName

        **QString QTextDocumentWriter::fileName() const**

        If the currently assigned device is a **QFile** , or if **setFileName**
        () has been called, this function returns the name of the file to be
        written to. In all other cases, it returns an empty string.

        **See also** **setFileName** () and **setDevice** ().
        """
        ...

    def setFileName(self, fileName: str) -> None:
        """
        https://doc.qt.io/qt-6/qtextdocumentwriter.html#setFileName

        **void QTextDocumentWriter::setFileName(const QString & fileName )**

        Sets the name of the file to be written to **fileName**. Internally,
        **QTextDocumentWriter**  will create a **QFile**  and open it in
        **WriteOnly**  mode, and use this file when writing the document.

        **See also** **fileName** () and **setDevice** ().
        """
        ...

    def device(self) -> QtCore.QIODevice:
        """
        https://doc.qt.io/qt-6/qtextdocumentwriter.html#device

        **QIODevice *QTextDocumentWriter::device() const**

        Returns the device currently assigned, or `nullptr` if no device has
        been assigned.

        **See also** **setDevice** ().
        """
        ...

    def setDevice(self, device: QtCore.QIODevice) -> None:
        """
        https://doc.qt.io/qt-6/qtextdocumentwriter.html#setDevice

        **void QTextDocumentWriter::setDevice(QIODevice * device )**

        Sets the writer's device to the **device** specified. If a device has
        already been set, the old device is removed but otherwise left
        unchanged.

        If the device is not already open, **QTextDocumentWriter**  will attempt
        to open the device in **WriteOnly**  mode by calling open().

        **Note:** This will not work for certain devices, such as **QProcess** ,
        **QTcpSocket**  and **QUdpSocket** , where some configuration is
        required before the device can be opened.

        **See also** **device** () and **setFileName** ().
        """
        ...

    def format(self) -> QtCore.QByteArray:
        """
        https://doc.qt.io/qt-6/qtextdocumentwriter.html#format

        **QByteArray QTextDocumentWriter::format() const**

        Returns the format used for writing documents.

        **See also** **setFormat** ().
        """
        ...

    def setFormat(self, format: QtCore.QByteArray) -> None:
        """
        https://doc.qt.io/qt-6/qtextdocumentwriter.html#setFormat

        **void QTextDocumentWriter::setFormat(const QByteArray & format )**

        Sets the format used to write documents to the **format** specified.
        **format** is a case insensitive text string. For example:

        **QTextDocumentWriter**  writer;
                    writer.setFormat("odf"); //
        same as writer.setFormat("ODF");

        You can call **supportedDocumentFormats** () for the full list of
        formats **QTextDocumentWriter**  supports.

        **See also** **format** ().
        """
        ...



"""
PySide stub files generated by **IceSpringPySideStubs**

Home: https://baijifeilong.github.io/2022/01/06/ice-spring-pyside-stubs/index.html

Github: https://github.com/baijifeilong/IceSpringPySideStubs

PyPI(PySide2): https://pypi.org/project/IceSpringPySideStubs-PySide2

PyPI(PySide6): https://pypi.org/project/IceSpringPySideStubs-PySide6

PyPI(PyQt5): https://pypi.org/project/IceSpringPySideStubs-PyQt5

PyPI(PyQt6): https://pypi.org/project/IceSpringPySideStubs-PyQt6

Generated by BaiJiFeiLong@gmail.com

License: MIT
"""
import enum
import typing
import PyQt6.sip
from PyQt6 import QtCore
from PyQt6.QtGui import *
import enum


class QPainterPath(PyQt6.sip.simplewrapper):
    """
    https://doc.qt.io/qt-6/qpainterpath.html

    **Detailed Description**

    A painter path is an object composed of a number of graphical building
    blocks, such as rectangles, ellipses, lines, and curves. Building blocks can
    be joined in closed subpaths, for example as a rectangle or an ellipse. A
    closed path has coinciding start and end points. Or they can exist
    independently as unclosed subpaths, such as lines and curves.

    A QPainterPath object can be used for filling, outlining, and clipping. To
    generate fillable outlines for a given painter path, use the
    **QPainterPathStroker**  class. The main advantage of painter paths over
    normal drawing operations is that complex shapes only need to be created
    once; then they can be drawn many times using only calls to the
    **QPainter::drawPath** () function.

    QPainterPath provides a collection of functions that can be used to obtain
    information about the path and its elements. In addition it is possible to
    reverse the order of the elements using the **toReversed** () function.
    There are also several functions to convert this painter path object into a
    polygon representation.

    **Composing a QPainterPath**

    A QPainterPath object can be constructed as an empty path, with a given
    start point, or as a copy of another QPainterPath object. Once created,
    lines and curves can be added to the path using the **lineTo** (), **arcTo**
    (), **cubicTo** () and **quadTo** () functions. The lines and curves stretch
    from the **currentPosition** () to the position passed as argument.

    The **currentPosition** () of the QPainterPath object is always the end
    position of the last subpath that was added (or the initial start point).
    Use the **moveTo** () function to move the **currentPosition** () without
    adding a component. The **moveTo** () function implicitly starts a new
    subpath, and closes the previous one. Another way of starting a new subpath
    is to call the **closeSubpath** () function which closes the current path by
    adding a line from the **currentPosition** () back to the path's start
    position. Note that the new path will have (0, 0) as its initial
    **currentPosition** ().

    QPainterPath class also provides several convenience functions to add closed
    subpaths to a painter path: **addEllipse** (), **addPath** (), **addRect**
    (), **addRegion** () and **addText** (). The **addPolygon** () function adds
    an **unclosed** subpath. In fact, these functions are all collections of
    **moveTo** (), **lineTo** () and **cubicTo** () operations.

    In addition, a path can be added to the current path using the
    **connectPath** () function. But note that this function will connect the
    last element of the current path to the first element of given one by adding
    a line.

    Below is a code snippet that shows how a QPainterPath object can be used:

    ![](images/qpainterpath-construction.png)



        **QPainterPath**
    path;
        path.addRect(20, 20, 60, 60);

        path.moveTo(0, 0);
    path.cubicTo(99, 0,  50, 50,  99, 99);
        path.cubicTo(0, 99,  50, 50,  0,
    0);

        **QPainter**  painter(this);
        painter.fillRect(0, 0, 100,
    100, Qt::white);
        painter.setPen(**QPen** (**QColor** (79, 106, 25), 1,
    Qt::SolidLine,
                            Qt::FlatCap, Qt::MiterJoin));
    painter.setBrush(**QColor** (122, 163, 39));
    painter.drawPath(path);

    The painter path is initially empty when constructed. We first add a
    rectangle, which is a closed subpath. Then we add two bezier curves which
    together form a closed subpath even though they are not closed individually.
    Finally we draw the entire path. The path is filled using the default fill
    rule, **Qt::OddEvenFill** . Qt provides two methods for filling paths:

    **Qt::OddEvenFill** **Qt::WindingFill**
    ![](images/qt-fillrule-
    oddeven.png)![](images/qt-fillrule-winding.png)

    See the **Qt::FillRule**  documentation for the definition of the rules. A
    painter path's currently set fill rule can be retrieved using the
    **fillRule** () function, and altered using the **setFillRule** () function.

    **QPainterPath Information**

    The QPainterPath class provides a collection of functions that returns
    information about the path and its elements.

    The **currentPosition** () function returns the end point of the last
    subpath that was added (or the initial start point). The **elementAt** ()
    function can be used to retrieve the various subpath elements, the
    **number** of elements can be retrieved using the **elementCount** ()
    function, and the **isEmpty** () function tells whether this QPainterPath
    object contains any elements at all.

    The **controlPointRect** () function returns the rectangle containing all
    the points and control points in this path. This function is significantly
    faster to compute than the exact **boundingRect** () which returns the
    bounding rectangle of this painter path with floating point precision.

    Finally, QPainterPath provides the **contains** () function which can be
    used to determine whether a given point or rectangle is inside the path, and
    the **intersects** () function which determines if any of the points inside
    a given rectangle also are inside this path.

    **QPainterPath Conversion**

    For compatibility reasons, it might be required to simplify the
    representation of a painter path: QPainterPath provides the
    **toFillPolygon** (), **toFillPolygons** () and **toSubpathPolygons** ()
    functions which convert the painter path into a polygon. The
    **toFillPolygon** () returns the painter path as one single polygon, while
    the two latter functions return a list of polygons.

    The **toFillPolygons** () and **toSubpathPolygons** () functions are
    provided because it is usually faster to draw several small polygons than to
    draw one large polygon, even though the total number of points drawn is the
    same. The difference between the two is the **number** of polygons they
    return: The **toSubpathPolygons** () creates one polygon for each subpath
    regardless of intersecting subpaths (i.e. overlapping bounding rectangles),
    while the **toFillPolygons** () functions creates only one polygon for
    overlapping subpaths.

    The **toFillPolygon** () and **toFillPolygons** () functions first convert
    all the subpaths to polygons, then uses a rewinding technique to make sure
    that overlapping subpaths can be filled using the correct fill rule. Note
    that rewinding inserts additional lines in the polygon so the outline of the
    fill polygon does not match the outline of the path.

    **Examples**

    Qt provides the **Painter Paths Example**  and the **Vector Deformation
    example**  which are located in Qt's example directory.

    The **Painter Paths Example**  shows how painter paths can be used to build
    complex shapes for rendering and lets the user experiment with the filling
    and stroking. The **Vector Deformation Example**  shows how to use
    QPainterPath to draw text.

    **Painter Paths Example** **Vector Deformation Example**
    ![](images/qpainterpath-example.png)![](images/qpainterpath-demo.png)

    **See also** **QPainterPathStroker** , **QPainter** , **QRegion** , and
    **Painter Paths Example** .
    """

    class ElementType(enum.Enum):
        MoveToElement: QPainterPath = ...
        LineToElement: QPainterPath = ...
        CurveToElement: QPainterPath = ...
        CurveToDataElement: QPainterPath = ...

    class Element(PyQt6.sip.simplewrapper):
        type = ...
        x: float = ...
        y: float = ...

        @typing.overload
        def __init__(self) -> None:
            ...

        @typing.overload
        def __init__(self, a0: "QPainterPath.Element") -> None:
            ...

        def isCurveTo(self) -> bool:
            ...

        def isLineTo(self) -> bool:
            ...

        def isMoveTo(self) -> bool:
            ...

    @typing.overload
    def __init__(self) -> None:
        """
        https://doc.qt.io/qt-6/qpainterpath.html#QPainterPath

        **QPainterPath::QPainterPath()**

        Constructs an empty QPainterPath object.
        """
        ...

    @typing.overload
    def __init__(self, startPoint: QtCore.QPointF) -> None:
        """
        https://doc.qt.io/qt-6/qpainterpath.html#QPainterPath-1

        **QPainterPath::QPainterPath(const QPointF & startPoint )**

        Creates a QPainterPath object with the given **startPoint** as its
        current position.
        """
        ...

    @typing.overload
    def __init__(self, other: "QPainterPath") -> None:
        """
        https://doc.qt.io/qt-6/qpainterpath.html#QPainterPath-2

        **QPainterPath::QPainterPath(const QPainterPath & path )**

        Creates a QPainterPath object that is a copy of the given **path**.

        **See also** **operator=** ().
        """
        ...

    def capacity(self) -> int:
        """
        https://doc.qt.io/qt-6/qpainterpath.html#capacity

        **[since 5.13] int QPainterPath::capacity() const**

        Returns the number of elements allocated by the **QPainterPath** .

        This function was introduced in Qt 5.13.

        **See also** **clear** () and **reserve** ().
        """
        ...

    def reserve(self, size: int) -> None:
        """
        https://doc.qt.io/qt-6/qpainterpath.html#reserve

        **[since 5.13] void QPainterPath::reserve(int size )**

        Reserves a given amount of elements in **QPainterPath** 's internal
        memory.

        Attempts to allocate memory for at least **size** elements.

        This function was introduced in Qt 5.13.

        **See also** **clear** (), **capacity** (), and **QList::reserve** ().
        """
        ...

    def clear(self) -> None:
        """
        https://doc.qt.io/qt-6/qpainterpath.html#clear

        **[since 5.13] void QPainterPath::clear()**

        Clears the path elements stored.

        This allows the path to reuse previous memory allocations.

        This function was introduced in Qt 5.13.

        **See also** **reserve** () and **capacity** ().
        """
        ...

    def swap(self, other: "QPainterPath") -> None:
        """
        https://doc.qt.io/qt-6/qpainterpath.html#swap

        **void QPainterPath::swap(QPainterPath & other )**

        Swaps painter path **other** with this painter path. This operation is
        very fast and never fails.
        """
        ...

    @typing.overload
    def translated(self, dx: float, dy: float) -> "QPainterPath":
        """
        https://doc.qt.io/qt-6/qpainterpath.html#translated

        **QPainterPath QPainterPath::translated(qreal dx , qreal dy ) const**

        Returns a copy of the path that is translated by ( **dx** , **dy** ).

        **See also** **translate** ().
        """
        ...

    @typing.overload
    def translated(self, offset: QtCore.QPointF) -> "QPainterPath":
        """
        https://doc.qt.io/qt-6/qpainterpath.html#translated-1

        **QPainterPath QPainterPath::translated(const QPointF & offset ) const**

        This is an overloaded function.

        Returns a copy of the path that is translated by the given **offset**.

        **See also** **translate** ().
        """
        ...

    @typing.overload
    def translate(self, dx: float, dy: float) -> None:
        """
        https://doc.qt.io/qt-6/qpainterpath.html#translate

        **void QPainterPath::translate(qreal dx , qreal dy )**

        Translates all elements in the path by ( **dx** , **dy** ).

        **See also** **translated** ().
        """
        ...

    @typing.overload
    def translate(self, offset: QtCore.QPointF) -> None:
        """
        https://doc.qt.io/qt-6/qpainterpath.html#translate-1

        **void QPainterPath::translate(const QPointF & offset )**

        This is an overloaded function.

        Translates all elements in the path by the given **offset**.

        **See also** **translated** ().
        """
        ...

    def simplified(self) -> "QPainterPath":
        """
        https://doc.qt.io/qt-6/qpainterpath.html#simplified

        **QPainterPath QPainterPath::simplified() const**

        Returns a simplified version of this path. This implies merging all
        subpaths that intersect, and returning a path containing no intersecting
        edges. Consecutive parallel lines will also be merged. The simplified
        path will always use the default fill rule, **Qt::OddEvenFill** . Bezier
        curves may be flattened to line segments due to numerical instability of
        doing bezier curve intersections.
        """
        ...

    @typing.overload
    def addRoundedRect(
        self,
        rect: QtCore.QRectF,
        xRadius: float,
        yRadius: float,
        mode: QtCore.Qt.SizeMode = ...,
    ) -> None:
        """
        https://doc.qt.io/qt-6/qpainterpath.html#addRoundedRect

        **void QPainterPath::addRoundedRect(const QRectF & rect , qreal xRadius
        , qreal yRadius , Qt::SizeMode mode = Qt::AbsoluteSize)**

        Adds the given rectangle **rect** with rounded corners to the path.

        The **xRadius** and **yRadius** arguments specify the radii of the
        ellipses defining the corners of the rounded rectangle. When **mode** is
        **Qt::RelativeSize** , **xRadius** and **yRadius** are specified in
        percentage of half the rectangle's width and height respectively, and
        should be in the range 0.0 to 100.0.

        **See also** **addRect** ().
        """
        ...

    @typing.overload
    def addRoundedRect(
        self,
        x: float,
        y: float,
        w: float,
        h: float,
        xRadius: float,
        yRadius: float,
        mode: QtCore.Qt.SizeMode = ...,
    ) -> None:
        """
        https://doc.qt.io/qt-6/qpainterpath.html#addRoundedRect-1

        **void QPainterPath::addRoundedRect(qreal x , qreal y , qreal w , qreal
        h , qreal xRadius , qreal yRadius , Qt::SizeMode mode =
        Qt::AbsoluteSize)**

        This is an overloaded function.

        Adds the given rectangle **x** , **y** , **w** , **h** with rounded
        corners to the path.
        """
        ...

    def subtracted(self, r: "QPainterPath") -> "QPainterPath":
        """
        https://doc.qt.io/qt-6/qpainterpath.html#subtracted

        **QPainterPath QPainterPath::subtracted(const QPainterPath & p ) const**

        Returns a path which is **p** 's fill area subtracted from this path's
        fill area.

        Set operations on paths will treat the paths as areas. Non-closed paths
        will be treated as implicitly closed. Bezier curves may be flattened to
        line segments due to numerical instability of doing bezier curve
        intersections.
        """
        ...

    def intersected(self, r: "QPainterPath") -> "QPainterPath":
        """
        https://doc.qt.io/qt-6/qpainterpath.html#intersected

        **QPainterPath QPainterPath::intersected(const QPainterPath & p )
        const**

        Returns a path which is the intersection of this path's fill area and
        **p** 's fill area. Bezier curves may be flattened to line segments due
        to numerical instability of doing bezier curve intersections.
        """
        ...

    def united(self, r: "QPainterPath") -> "QPainterPath":
        """
        https://doc.qt.io/qt-6/qpainterpath.html#united

        **QPainterPath QPainterPath::united(const QPainterPath & p ) const**

        Returns a path which is the union of this path's fill area and **p** 's
        fill area.

        Set operations on paths will treat the paths as areas. Non-closed paths
        will be treated as implicitly closed. Bezier curves may be flattened to
        line segments due to numerical instability of doing bezier curve
        intersections.

        **See also** **intersected** () and **subtracted** ().
        """
        ...

    def slopeAtPercent(self, t: float) -> float:
        """
        https://doc.qt.io/qt-6/qpainterpath.html#slopeAtPercent

        **qreal QPainterPath::slopeAtPercent(qreal t ) const**

        Returns the slope of the path at the percentage **t**. The argument
        **t** has to be between 0 and 1.

        Note that similarly to other percent methods, the percentage measurement
        is not linear with regards to the length, if curves are present in the
        path. When curves are present the percentage argument is mapped to the t
        parameter of the Bezier equations.
        """
        ...

    def angleAtPercent(self, t: float) -> float:
        """
        https://doc.qt.io/qt-6/qpainterpath.html#angleAtPercent

        **qreal QPainterPath::angleAtPercent(qreal t ) const**

        Returns the angle of the path tangent at the percentage **t**. The
        argument **t** has to be between 0 and 1.

        Positive values for the angles mean counter-clockwise while negative
        values mean the clockwise direction. Zero degrees is at the 3 o'clock
        position.

        Note that similarly to the other percent methods, the percentage
        measurement is not linear with regards to the length if curves are
        present in the path. When curves are present the percentage argument is
        mapped to the t parameter of the Bezier equations.
        """
        ...

    def pointAtPercent(self, t: float) -> QtCore.QPointF:
        """
        https://doc.qt.io/qt-6/qpainterpath.html#pointAtPercent

        **QPointF QPainterPath::pointAtPercent(qreal t ) const**

        Returns the point at at the percentage **t** of the current path. The
        argument **t** has to be between 0 and 1.

        Note that similarly to other percent methods, the percentage measurement
        is not linear with regards to the length, if curves are present in the
        path. When curves are present the percentage argument is mapped to the t
        parameter of the Bezier equations.
        """
        ...

    def percentAtLength(self, t: float) -> float:
        """
        https://doc.qt.io/qt-6/qpainterpath.html#percentAtLength

        **qreal QPainterPath::percentAtLength(qreal len ) const**

        Returns percentage of the whole path at the specified length **len**.

        Note that similarly to other percent methods, the percentage measurement
        is not linear with regards to the length, if curves are present in the
        path. When curves are present the percentage argument is mapped to the t
        parameter of the Bezier equations.
        """
        ...

    def length(self) -> float:
        """
        https://doc.qt.io/qt-6/qpainterpath.html#length

        **qreal QPainterPath::length() const**

        Returns the length of the current path.
        """
        ...

    def setElementPositionAt(self, i: int, x: float, y: float) -> None:
        """
        https://doc.qt.io/qt-6/qpainterpath.html#setElementPositionAt

        **void QPainterPath::setElementPositionAt(int index , qreal x , qreal y
        )**

        Sets the x and y coordinate of the element at index **index** to **x**
        and **y**.
        """
        ...

    def elementAt(self, i: int) -> "QPainterPath.Element":
        """
        https://doc.qt.io/qt-6/qpainterpath.html#elementAt

        **QPainterPath::Element QPainterPath::elementAt(int index ) const**

        Returns the element at the given **index** in the painter path.

        **See also** **ElementType** , **elementCount** (), and **isEmpty** ().
        """
        ...

    def elementCount(self) -> int:
        """
        https://doc.qt.io/qt-6/qpainterpath.html#elementCount

        **int QPainterPath::elementCount() const**

        Returns the number of path elements in the painter path.

        **See also** **ElementType** , **elementAt** (), and **isEmpty** ().
        """
        ...

    def isEmpty(self) -> bool:
        """
        https://doc.qt.io/qt-6/qpainterpath.html#isEmpty

        **bool QPainterPath::isEmpty() const**

        Returns `true` if either there are no elements in this path, or if the
        only element is a **MoveToElement** ; otherwise returns `false`.

        **See also** **elementCount** ().
        """
        ...

    @typing.overload
    def arcMoveTo(self, rect: QtCore.QRectF, angle: float) -> None:
        """
        https://doc.qt.io/qt-6/qpainterpath.html#arcMoveTo

        **void QPainterPath::arcMoveTo(const QRectF & rectangle , qreal angle
        )**

        Creates a move to that lies on the arc that occupies the given
        **rectangle** at **angle**.

        Angles are specified in degrees. Clockwise arcs can be specified using
        negative angles.

        **See also** **moveTo** () and **arcTo** ().
        """
        ...

    @typing.overload
    def arcMoveTo(self, x: float, y: float, w: float, h: float, angle: float) -> None:
        """
        https://doc.qt.io/qt-6/qpainterpath.html#arcMoveTo-1

        **void QPainterPath::arcMoveTo(qreal x , qreal y , qreal width , qreal
        height , qreal angle )**

        This is an overloaded function.

        Creates a move to that lies on the arc that occupies the **QRectF** (
        **x** , **y** , **width** , **height** ) at **angle**.
        """
        ...

    def toFillPolygon(self, matrix: "QTransform" = ...) -> "QPolygonF":
        """
        https://doc.qt.io/qt-6/qpainterpath.html#toFillPolygon

        **QPolygonF QPainterPath::toFillPolygon(const QTransform & matrix =
        QTransform()) const**

        Converts the path into a polygon using the **QTransform**  **matrix** ,
        and returns the polygon.

        The polygon is created by first converting all subpaths to polygons,
        then using a rewinding technique to make sure that overlapping subpaths
        can be filled using the correct fill rule.

        Note that rewinding inserts addition lines in the polygon so the outline
        of the fill polygon does not match the outline of the path.

        **See also** **toSubpathPolygons** (), **toFillPolygons** (), and
        **QPainterPath Conversion** .
        """
        ...

    def toFillPolygons(self, matrix: "QTransform" = ...) -> typing.List["QPolygonF"]:
        """
        https://doc.qt.io/qt-6/qpainterpath.html#toFillPolygons

        **QList<QPolygonF> QPainterPath::toFillPolygons(const QTransform &
        matrix = QTransform()) const**

        Converts the path into a list of polygons using the **QTransform**
        **matrix** , and returns the list.

        The function differs from the **toFillPolygon** () function in that it
        creates several polygons. It is provided because it is usually faster to
        draw several small polygons than to draw one large polygon, even though
        the total number of points drawn is the same.

        The toFillPolygons() function differs from the **toSubpathPolygons** ()
        function in that it create only polygon for subpaths that have
        overlapping bounding rectangles.

        Like the **toFillPolygon** () function, this function uses a rewinding
        technique to make sure that overlapping subpaths can be filled using the
        correct fill rule. Note that rewinding inserts addition lines in the
        polygons so the outline of the fill polygon does not match the outline
        of the path.

        **See also** **toSubpathPolygons** (), **toFillPolygon** (), and
        **QPainterPath Conversion** .
        """
        ...

    def toSubpathPolygons(self, matrix: "QTransform" = ...) -> typing.List["QPolygonF"]:
        """
        https://doc.qt.io/qt-6/qpainterpath.html#toSubpathPolygons

        **QList<QPolygonF> QPainterPath::toSubpathPolygons(const QTransform &
        matrix = QTransform()) const**

        Converts the path into a list of polygons using the **QTransform**
        **matrix** , and returns the list.

        This function creates one polygon for each subpath regardless of
        intersecting subpaths (i.e. overlapping bounding rectangles). To make
        sure that such overlapping subpaths are filled correctly, use the
        **toFillPolygons** () function instead.

        **See also** **toFillPolygons** (), **toFillPolygon** (), and
        **QPainterPath Conversion** .
        """
        ...

    def toReversed(self) -> "QPainterPath":
        """
        https://doc.qt.io/qt-6/qpainterpath.html#toReversed

        **QPainterPath QPainterPath::toReversed() const**

        Creates and returns a reversed copy of the path.

        It is the order of the elements that is reversed: If a **QPainterPath**
        is composed by calling the **moveTo** (), **lineTo** () and **cubicTo**
        () functions in the specified order, the reversed copy is composed by
        calling **cubicTo** (), **lineTo** () and **moveTo** ().
        """
        ...

    def setFillRule(self, fillRule: QtCore.Qt.FillRule) -> None:
        """
        https://doc.qt.io/qt-6/qpainterpath.html#setFillRule

        **void QPainterPath::setFillRule(Qt::FillRule fillRule )**

        Sets the fill rule of the painter path to the given **fillRule**. Qt
        provides two methods for filling paths:

        **Qt::OddEvenFill**  (default)**Qt::WindingFill**
        ![](images/qt-
        fillrule-oddeven.png)![](images/qt-fillrule-winding.png)

        **See also** **fillRule** ().
        """
        ...

    def fillRule(self) -> QtCore.Qt.FillRule:
        """
        https://doc.qt.io/qt-6/qpainterpath.html#fillRule

        **Qt::FillRule QPainterPath::fillRule() const**

        Returns the painter path's currently set fill rule.

        **See also** **setFillRule** ().
        """
        ...

    def controlPointRect(self) -> QtCore.QRectF:
        """
        https://doc.qt.io/qt-6/qpainterpath.html#controlPointRect

        **QRectF QPainterPath::controlPointRect() const**

        Returns the rectangle containing all the points and control points in
        this path.

        This function is significantly faster to compute than the exact
        **boundingRect** (), and the returned rectangle is always a superset of
        the rectangle returned by **boundingRect** ().

        **See also** **boundingRect** ().
        """
        ...

    def boundingRect(self) -> QtCore.QRectF:
        """
        https://doc.qt.io/qt-6/qpainterpath.html#boundingRect

        **QRectF QPainterPath::boundingRect() const**

        Returns the bounding rectangle of this painter path as a rectangle with
        floating point precision.

        **See also** **controlPointRect** ().
        """
        ...

    @typing.overload
    def intersects(self, rect: QtCore.QRectF) -> bool:
        """
        https://doc.qt.io/qt-6/qpainterpath.html#intersects

        **bool QPainterPath::intersects(const QRectF & rectangle ) const**

        Returns `true` if any point in the given **rectangle** intersects the
        path; otherwise returns `false`.

        There is an intersection if any of the lines making up the rectangle
        crosses a part of the path or if any part of the rectangle overlaps with
        any area enclosed by the path. This function respects the current
        **fillRule**  to determine what is considered inside the path.

        **See also** **contains** ().
        """
        ...

    @typing.overload
    def intersects(self, p: "QPainterPath") -> bool:
        """
        https://doc.qt.io/qt-6/qpainterpath.html#intersects-1

        **bool QPainterPath::intersects(const QPainterPath & p ) const**

        Returns `true` if the current path intersects at any point the given
        path **p**. Also returns `true` if the current path contains or is
        contained by any part of **p**.

        Set operations on paths will treat the paths as areas. Non-closed paths
        will be treated as implicitly closed.

        **See also** **contains** ().
        """
        ...

    @typing.overload
    def contains(self, pt: QtCore.QPointF) -> bool:
        """
        https://doc.qt.io/qt-6/qpainterpath.html#contains

        **bool QPainterPath::contains(const QPointF & point ) const**

        Returns `true` if the given **point** is inside the path, otherwise
        returns `false`.

        **See also** **intersects** ().
        """
        ...

    @typing.overload
    def contains(self, rect: QtCore.QRectF) -> bool:
        """
        https://doc.qt.io/qt-6/qpainterpath.html#contains-1

        **bool QPainterPath::contains(const QRectF & rectangle ) const**

        Returns `true` if the given **rectangle** is inside the path, otherwise
        returns `false`.
        """
        ...

    @typing.overload
    def contains(self, p: "QPainterPath") -> bool:
        """
        https://doc.qt.io/qt-6/qpainterpath.html#contains-2

        **bool QPainterPath::contains(const QPainterPath & p ) const**

        Returns `true` if the given path **p** is contained within the current
        path. Returns `false` if any edges of the current path and **p**
        intersect.

        Set operations on paths will treat the paths as areas. Non-closed paths
        will be treated as implicitly closed.

        **See also** **intersects** ().
        """
        ...

    def connectPath(self, path: "QPainterPath") -> None:
        """
        https://doc.qt.io/qt-6/qpainterpath.html#connectPath

        **void QPainterPath::connectPath(const QPainterPath & path )**

        Connects the given **path** to **this** path by adding a line from the
        last element of this path to the first element of the given path.

        **See also** **addPath** () and **Composing a QPainterPath** .
        """
        ...

    def addRegion(self, region: "QRegion") -> None:
        """
        https://doc.qt.io/qt-6/qpainterpath.html#addRegion

        **void QPainterPath::addRegion(const QRegion & region )**

        Adds the given **region** to the path by adding each rectangle in the
        region as a separate closed subpath.

        **See also** **addRect** () and **Composing a QPainterPath** .
        """
        ...

    def addPath(self, path: "QPainterPath") -> None:
        """
        https://doc.qt.io/qt-6/qpainterpath.html#addPath

        **void QPainterPath::addPath(const QPainterPath & path )**

        Adds the given **path** to **this** path as a closed subpath.

        **See also** **connectPath** () and **Composing a QPainterPath** .
        """
        ...

    @typing.overload
    def addText(self, point: QtCore.QPointF, f: QFont, text: str) -> None:
        """
        https://doc.qt.io/qt-6/qpainterpath.html#addText

        **void QPainterPath::addText(const QPointF & point , const QFont & font
        , const QString & text )**

        Adds the given **text** to this path as a set of closed subpaths created
        from the **font** supplied. The subpaths are positioned so that the left
        end of the text's baseline lies at the specified **point**.

        ![](images/qpainterpath-addtext.png)



            **QLinearGradient**
        myGradient;
            **QPen**  myPen;
            **QFont**  myFont;
            **QPointF**
        baseline(x, y);

            **QPainterPath**  myPath;
        myPath.addText(baseline, myFont, tr("Qt"));

            **QPainter**
        painter(this);
            painter.setBrush(myGradient);
        painter.setPen(myPen);
            painter.drawPath(myPath);

        **See also** **QPainter::drawText** () and **Composing a QPainterPath**
        .
        """
        ...

    @typing.overload
    def addText(self, x: float, y: float, f: QFont, text: str) -> None:
        """
        https://doc.qt.io/qt-6/qpainterpath.html#addText-1

        **void QPainterPath::addText(qreal x , qreal y , const QFont & font ,
        const QString & text )**

        This is an overloaded function.

        Adds the given **text** to this path as a set of closed subpaths created
        from the **font** supplied. The subpaths are positioned so that the left
        end of the text's baseline lies at the point specified by ( **x** ,
        **y** ).
        """
        ...

    def addPolygon(self, polygon: "QPolygonF") -> None:
        """
        https://doc.qt.io/qt-6/qpainterpath.html#addPolygon

        **void QPainterPath::addPolygon(const QPolygonF & polygon )**

        Adds the given **polygon** to the path as an (unclosed) subpath.

        Note that the current position after the polygon has been added, is the
        last point in **polygon**. To draw a line back to the first point, use
        the **closeSubpath** () function.

        ![](images/qpainterpath-addpolygon.png)
        **QLinearGradient**  myGradient;
            **QPen**  myPen;
            **QPolygonF**
        myPolygon;

            **QPainterPath**  myPath;
        myPath.addPolygon(myPolygon);

            **QPainter**  painter(this);
        painter.setBrush(myGradient);
            painter.setPen(myPen);
        painter.drawPath(myPath);

        **See also** **lineTo** () and **Composing a QPainterPath** .
        """
        ...

    @typing.overload
    def addEllipse(self, rect: QtCore.QRectF) -> None:
        """
        https://doc.qt.io/qt-6/qpainterpath.html#addEllipse

        **void QPainterPath::addEllipse(const QRectF & boundingRectangle )**

        Creates an ellipse within the specified **boundingRectangle** and adds
        it to the painter path as a closed subpath.

        The ellipse is composed of a clockwise curve, starting and finishing at
        zero degrees (the 3 o'clock position).

        ![](images/qpainterpath-addellipse.png)
        **QLinearGradient**  myGradient;
            **QPen**  myPen;
            **QRectF**
        boundingRectangle;

            **QPainterPath**  myPath;
        myPath.addEllipse(boundingRectangle);

            **QPainter**
        painter(this);
            painter.setBrush(myGradient);
        painter.setPen(myPen);
            painter.drawPath(myPath);

        **See also** **arcTo** (), **QPainter::drawEllipse** (), and **Composing
        a QPainterPath** .
        """
        ...

    @typing.overload
    def addEllipse(self, x: float, y: float, w: float, h: float) -> None:
        """
        https://doc.qt.io/qt-6/qpainterpath.html#addEllipse-1

        **void QPainterPath::addEllipse(qreal x , qreal y , qreal width , qreal
        height )**

        This is an overloaded function.

        Creates an ellipse within the bounding rectangle defined by its top-left
        corner at ( **x** , **y** ), **width** and **height** , and adds it to
        the painter path as a closed subpath.
        """
        ...

    @typing.overload
    def addEllipse(self, center: QtCore.QPointF, rx: float, ry: float) -> None:
        """
        https://doc.qt.io/qt-6/qpainterpath.html#addEllipse-2

        **void QPainterPath::addEllipse(const QPointF & center , qreal rx ,
        qreal ry )**

        This is an overloaded function.

        Creates an ellipse positioned at **center** with radii **rx** and **ry**
        , and adds it to the painter path as a closed subpath.
        """
        ...

    @typing.overload
    def addRect(self, rect: QtCore.QRectF) -> None:
        """
        https://doc.qt.io/qt-6/qpainterpath.html#addRect

        **void QPainterPath::addRect(const QRectF & rectangle )**

        Adds the given **rectangle** to this path as a closed subpath.

        The **rectangle** is added as a clockwise set of lines. The painter
        path's current position after the **rectangle** has been added is at the
        top-left corner of the rectangle.

        ![](images/qpainterpath-addrectangle.png)
        **QLinearGradient**  myGradient;
            **QPen**  myPen;
            **QRectF**
        myRectangle;

            **QPainterPath**  myPath;
        myPath.addRect(myRectangle);

            **QPainter**  painter(this);
        painter.setBrush(myGradient);
            painter.setPen(myPen);
        painter.drawPath(myPath);

        **See also** **addRegion** (), **lineTo** (), and **Composing a
        QPainterPath** .
        """
        ...

    @typing.overload
    def addRect(self, x: float, y: float, w: float, h: float) -> None:
        """
        https://doc.qt.io/qt-6/qpainterpath.html#addRect-1

        **void QPainterPath::addRect(qreal x , qreal y , qreal width , qreal
        height )**

        This is an overloaded function.

        Adds a rectangle at position ( **x** , **y** ), with the given **width**
        and **height** , as a closed subpath.
        """
        ...

    def currentPosition(self) -> QtCore.QPointF:
        """
        https://doc.qt.io/qt-6/qpainterpath.html#currentPosition

        **QPointF QPainterPath::currentPosition() const**

        Returns the current position of the path.
        """
        ...

    @typing.overload
    def quadTo(self, ctrlPt: QtCore.QPointF, endPt: QtCore.QPointF) -> None:
        """
        https://doc.qt.io/qt-6/qpainterpath.html#quadTo

        **void QPainterPath::quadTo(const QPointF & c , const QPointF & endPoint
        )**

        Adds a quadratic Bezier curve between the current position and the given
        **endPoint** with the control point specified by **c**.

        After the curve is added, the current point is updated to be at the end
        point of the curve.

        **See also** **cubicTo** () and **Composing a QPainterPath** .
        """
        ...

    @typing.overload
    def quadTo(
        self, ctrlPtx: float, ctrlPty: float, endPtx: float, endPty: float
    ) -> None:
        """
        https://doc.qt.io/qt-6/qpainterpath.html#quadTo-1

        **void QPainterPath::quadTo(qreal cx , qreal cy , qreal endPointX ,
        qreal endPointY )**

        This is an overloaded function.

        Adds a quadratic Bezier curve between the current point and the endpoint
        ( **endPointX** , **endPointY** ) with the control point specified by (
        **cx** , **cy** ).
        """
        ...

    @typing.overload
    def cubicTo(
        self, ctrlPt1: QtCore.QPointF, ctrlPt2: QtCore.QPointF, endPt: QtCore.QPointF
    ) -> None:
        """
        https://doc.qt.io/qt-6/qpainterpath.html#cubicTo

        **void QPainterPath::cubicTo(const QPointF & c1 , const QPointF & c2 ,
        const QPointF & endPoint )**

        Adds a cubic Bezier curve between the current position and the given
        **endPoint** using the control points specified by **c1** , and **c2**.

        After the curve is added, the current position is updated to be at the
        end point of the curve.

        ![](images/qpainterpath-cubicto.png)



            **QLinearGradient**
        myGradient;
            **QPen**  myPen;

            **QPainterPath**  myPath;
        myPath.cubicTo(c1, c2, endPoint);

            **QPainter**  painter(this);
        painter.setBrush(myGradient);
            painter.setPen(myPen);
        painter.drawPath(myPath);

        **See also** **quadTo** () and **Composing a QPainterPath** .
        """
        ...

    @typing.overload
    def cubicTo(
        self,
        ctrlPt1x: float,
        ctrlPt1y: float,
        ctrlPt2x: float,
        ctrlPt2y: float,
        endPtx: float,
        endPty: float,
    ) -> None:
        """
        https://doc.qt.io/qt-6/qpainterpath.html#cubicTo-1

        **void QPainterPath::cubicTo(qreal c1X , qreal c1Y , qreal c2X , qreal
        c2Y , qreal endPointX , qreal endPointY )**

        This is an overloaded function.

        Adds a cubic Bezier curve between the current position and the end point
        ( **endPointX** , **endPointY** ) with control points specified by (
        **c1X** , **c1Y** ) and ( **c2X** , **c2Y** ).
        """
        ...

    @typing.overload
    def arcTo(self, rect: QtCore.QRectF, startAngle: float, arcLength: float) -> None:
        """
        https://doc.qt.io/qt-6/qpainterpath.html#arcTo

        **void QPainterPath::arcTo(const QRectF & rectangle , qreal startAngle ,
        qreal sweepLength )**

        Creates an arc that occupies the given **rectangle** , beginning at the
        specified **startAngle** and extending **sweepLength** degrees counter-
        clockwise.

        Angles are specified in degrees. Clockwise arcs can be specified using
        negative angles.

        Note that this function connects the starting point of the arc to the
        current position if they are not already connected. After the arc has
        been added, the current position is the last point in arc. To draw a
        line back to the first point, use the **closeSubpath** () function.

        ![](images/qpainterpath-arcto.png)



            **QPainterPath**
        myPath;
            myPath.moveTo(center);
            myPath.arcTo(boundingRect,
        startAngle,
                         sweepLength);

            **QPainter**
        painter(this);
            painter.setBrush(myGradient);
        painter.setPen(myPen);
            painter.drawPath(myPath);

        **See also** **arcMoveTo** (), **addEllipse** (), **QPainter::drawArc**
        (), **QPainter::drawPie** (), and **Composing a QPainterPath** .
        """
        ...

    @typing.overload
    def arcTo(
        self,
        x: float,
        y: float,
        w: float,
        h: float,
        startAngle: float,
        arcLenght: float,
    ) -> None:
        """
        https://doc.qt.io/qt-6/qpainterpath.html#arcTo-1

        **void QPainterPath::arcTo(qreal x , qreal y , qreal width , qreal
        height , qreal startAngle , qreal sweepLength )**

        This is an overloaded function.

        Creates an arc that occupies the rectangle **QRectF** ( **x** , **y** ,
        **width** , **height** ), beginning at the specified **startAngle** and
        extending **sweepLength** degrees counter-clockwise.
        """
        ...

    @typing.overload
    def lineTo(self, p: QtCore.QPointF) -> None:
        """
        https://doc.qt.io/qt-6/qpainterpath.html#lineTo

        **void QPainterPath::lineTo(const QPointF & endPoint )**

        Adds a straight line from the current position to the given
        **endPoint**. After the line is drawn, the current position is updated
        to be at the end point of the line.

        **See also** **addPolygon** (), **addRect** (), and **Composing a
        QPainterPath** .
        """
        ...

    @typing.overload
    def lineTo(self, x: float, y: float) -> None:
        """
        https://doc.qt.io/qt-6/qpainterpath.html#lineTo-1

        **void QPainterPath::lineTo(qreal x , qreal y )**

        This is an overloaded function.

        Draws a line from the current position to the point ( **x** , **y** ).
        """
        ...

    @typing.overload
    def moveTo(self, p: QtCore.QPointF) -> None:
        """
        https://doc.qt.io/qt-6/qpainterpath.html#moveTo

        **void QPainterPath::moveTo(const QPointF & point )**

        Moves the current point to the given **point** , implicitly starting a
        new subpath and closing the previous one.

        **See also** **closeSubpath** () and **Composing a QPainterPath** .
        """
        ...

    @typing.overload
    def moveTo(self, x: float, y: float) -> None:
        """
        https://doc.qt.io/qt-6/qpainterpath.html#moveTo-1

        **void QPainterPath::moveTo(qreal x , qreal y )**

        This is an overloaded function.

        Moves the current position to ( **x** , **y** ) and starts a new
        subpath, implicitly closing the previous path.
        """
        ...

    def closeSubpath(self) -> None:
        """
        https://doc.qt.io/qt-6/qpainterpath.html#closeSubpath

        **void QPainterPath::closeSubpath()**

        Closes the current subpath by drawing a line to the beginning of the
        subpath, automatically starting a new path. The current point of the new
        path is (0, 0).

        If the subpath does not contain any elements, this function does
        nothing.

        **See also** **moveTo** () and **Composing a QPainterPath** .
        """
        ...
